# Transcript: lIhFMlUfJ8Y

- **Language**: English (auto-generated)
- **Language Code**: en
- **Auto-generated**: True
- **Total Segments**: 1337
- **Total Duration**: 84m 26s

## Full Text

If I lost my YouTube channel tomorrow and had to start over, I'd do it very differently because what's working now is completely different from what's working even a year ago. So, in this video, we're going to take you through the last 6 years of [music] building a YouTube channel to over 1.3 million subscribers. We're going to give you a clear road map on how to build a YouTube [music] channel that generates income and could potentially replace your day job. Well, before we get to the actual steps, I think there's one very important question that everyone needs to answer before they start a YouTube channel. Why do you want to build a YouTube channel in the first place? Do you want to be famous? Do you want to get a lot of views? Do you want to make money? Or do you want to just have a side project for fun? Because if you don't really know what you're going to build, you're going to end up building the wrong thing. >> And we've seen out there that you can have a lot of subscribers, but not a lot of money. And the other way around, you can have not very many subscribers and still make a great amount of money. >> So, we've worked with dozens of creators. We've studied thousands of YouTube videos. And there are only three types of channels that consistently work on YouTube. The first type of channel are the entertainment channels, right? Think about Mr. Beast, any gaming channel, reaction channels, >> skits. So, the second type of channel is the educational channel. And this type of channel is not to be confused with like Con Academy or like a study type of channel, right? This is a channel that people go to to learn, >> right? Because at the end of the day, YouTube is a search platform where people go and type in their questions if they have problems that they need answers to. So you can learn anything from YouTube nowadays, YouTube University. So a few examples here. Of course, our channel, we teach YouTube, but one of my favorite niches is business education. So people like Alex Herozi, Leila Heroszi, Cody Sanchez, but really you can learn about anything you want. Just name it, search it, and you'll probably find the most niche educational content. The third type of channel is an empowerment channel. Empowerment channels are channels that are focused on good vibes or relaxation or motivation. Examples of these, the biggest example is like what chill cow or uh I love that. >> Chillhop radio, stuff like that. Or like any circle I do like music sets, >> boiler room, that's a good example of it. Study with me, that's a big one, too. Work with me, 8 hours of stoicism to fall asleep to, you know, like these long channels that are just meant for vibes or just like good scenery and background. So these are the three channels that you can make. Again, there's no wrong channel you can pick. It's just asking the question like, "What kind of channel do I want to build?" So you don't accidentally build something that you don't want to build. Now, of these three channels though, our favorite type of channel and the channel that we believe is going to be like the the ones with the most leverage for the future are the educational channels. >> Mhm. [clears throat] >> These are channels that specifically help people solve some kind of problem. This is something I learned about YouTube a few years into our YouTube journey. YouTube is a business and businesses solve problems and businesses make money. So those two things go hand in hand. And so if we're trying to build a YouTube channel that makes money, then an educational channel has the highest upside. I think in 2026, an educational channel has the like outsiz returns >> compared to these other channels. >> I'll also say that the vast majority of YouTube content is entertainment. So what that means is that there is a big gap in educational content. We need more of that. If you have something to teach and you have problems to solve, then there's not as much competition as if you were to make an entertainment channel, >> right? And it might feel like, you know, there are so many creators joining the game right now, but you were still pretty early. But that window is closing because of AI and how quickly you can start to build a channel and grow something quickly. So, if you ever want to start a YouTube channel, like 2026 is a great time and potentially like one of the last years when it might be quote unquote easy to blow up on social media. >> And the educational type of content holds a special place in my heart. Way back when we first started YouTube, we were looking for a way to actually use what we already had. So, we already had knowledge from 10 years of studying to become doctors. That's what we were before we did all this stuff. And actually, YouTube allowed us to quit our jobs as doctors because of the ability for us to teach online and reach way more people than we ever could have as doctors. When we went full-time into YouTube, I was like in my early 30s. And to me, I felt that sense of urgency because I wanted to start a family soon and I didn't want to spend the next 10 years of my life building a business from scratch. So using our knowledge and starting from there was actually the highest leverage point that we could have done. So that is the reason why we chose educational channel of all these three. So for the rest of this video, we're going to be talking specifically about educational channel because we think that that's the greatest opportunity. But just know that the lessons that we teach here, they're going to apply to every single kind. So now that we know what kind of channel we're looking to build, the next question is what type of content should we make? aka when everyone says, "What's the niche we should pick for our channel?" Honestly, the longer I've been on YouTube, the more I think that's the wrong question to ask. I think a much better question is, "What is the transformation that you want your viewer to have from watching your content?" Because it really targets a person, your target audience, instead of like just a general general ambiguous term, right? >> Yeah. Yeah, I mean if you want to think about it very simply, you're defining who is watching your videos >> and you're defining why they're watching your videos. But the word transformation, it also implies that people are going to be impacted by your content, >> right? Their lives are going to change in some way. And as creators, that's what we ultimately want, right? We want our content to have meaning, to have impact on people. >> So let's do a few examples about like what's the difference between a niche and a transformation, just so it's like super clear. >> Okay. Um, let's start with our channel as an example. So, when we were growing our channel Koi for the beginning, we thought the channel was a study channel, but study is a pretty general term. There's a lot of different content that can be for study. So, you can have channels where they teach you how to study, like the study techniques and strategies. You can have a study with me channel where the person probably doesn't even say anything. They're just sitting there and studying. >> There's like study vlog channels where no face and they just walk around. This is my day as a student. So, we went from just a study channel to our transformation being we're going to help students get better grades through evidence-based learning skills. >> And real quickly, let's just draw a visual for what actually is a transformation. So, transformation is you're helping take someone from a point A to a point B. >> Like that's the most simplest terms we can say it, >> right? So, you go from sad to happy. you go from poor to rich. >> So, if you've been watching this channel, we are evolving because the world has gotten a little bit crazy and we don't really believe that getting better grades is a the ultimate transformation that you should be shooting for. I think that learning skills is really important, but what you do with those skills now is not just to get better grades, it's to build self-reliance. It's to get better paying work because you can't really rely on grades and degrees to get you good jobs anymore. And we're entering what you would call the business niche. But business again, like if you write business down on the niche side, there's so much types of business content out there. Manufacturing businesses, there's online business, there's creator economy business, >> there's Shark Tank. >> There's Shark Tank. >> Yeah. Well, like if you say business content, it's not really clear like, okay, what kind of business content am I making? So, our transformation right now, what would you say it is? >> Yeah. I would say it's make money with YouTube. >> Mhm. >> So, you're starting from point A. I have a YouTube channel that doesn't really make me much income. >> Mhm. to point B. I have a YouTube channel that does make me income >> and then all the, you know, perks and benefits that comes with a profitable YouTube channel. So, the whole point of shifting from niche transformation is to really help the target viewer know, is this channel for me? Did this creator make content that I actually want to watch? In fact, like if you focus on a transformation, you're actually going to grow your channel a lot faster, too. Because going from niche to transformation, this is what the YouTube algorithm is is trying to do every single day when it matches content to you. In the past, you would see channels on your homepage from creators that you actually subscribe to. Nowadays, that's flipped. There's a lot of pros and cons in that. Obviously, if you're a new creator, you're a new channel, then YouTube is actively helping these channels grow and get some viewership. If you don't make content that is very specific for transformation, then you're not going to get your content promoted. I think a lot of channels that used to make content that was all over the place are seeing a huge drop in viewership. That's kind of what happened on our channel Koi for a little bit too and we tried to switch the transformation too quickly and it didn't really reward us. >> What you said before there is also very important especially for this year is that you're seeing just regular people like normal people blowing up on YouTube. Like I don't know how many you've seen like when you're scrolling through your phone. I have seen channels that have like hundreds of subscribers. I've seen videos that have like 20 views. >> Yeah. >> The thing is that those videos that are recommended to me, >> they are on the exact topics that I was watching like yesterday or like I was watching an hour ago. >> Sometimes I will give those videos a chance [laughter] >> sometimes >> and I will click on them and they are terrible. >> But other times I have found some gems of a channel >> and I was thankful that it was served to me. The only thing that matters is can you make just really really really good content. >> Yeah. >> If you can do that, then you will blow up. Like it's that simple. >> People say you blow up quote unquote overnight, but that's not actually the case. So I discovered this channel called Superordinary. And when I found him, he had like a hundred subs or something and his videos had like barely any views. But when I watched it, it was like a cinematic masterpiece. And I was like, "This guy is going to blow up overnight." But he had spent probably 10 years of his life before that working on these skills being able to create such cinematic masterpieces. >> So if you already have knowledge that you have acred for years, a diploma that took you so many years to get, then you can blow up overnight. When you speak with confidence on what you're teaching, people can see that authority right away >> and they will follow you. >> I mean, honestly, like when creators come to us and say, "Hey, I want to start a channel, but I don't know what I should make content about." this is the exact question that they're stumped with and most people quit right here because they just get stuck in analysis paralysis of not knowing what kind of content to make and then just never making content. >> You can check out our free tool. We actually have a lot of frameworks on how to figure this out. It does the thinking for you. So check out that free tool link in the description. >> So now that we've picked the transformation that we want our channel to accomplish, it's now time to move on to the content strategy for growing on YouTube. How often should I post that content? So, if you've been watching any YouTube at all, then that's probably going to kind of sway you and give you clues on what content you might want to try because there's a lot of different what we call formats to making YouTube videos. Format is basically just a structure on how you make your videos. So, the reason we want to pick a format is because YouTube really rewards channels that give their audience the same thing over and over and over, right? I'll I'll give an example of what I mean by this. So, I think a couple years ago, maybe it was last year, there was this channel that blew up called Easy Actually. The first video that he posted on the channel that blew up was becoming smart is easy actually. And then the next video he posted was like losing weight is easy actually. And he just kept following up everything over and over using the same exact format of like doing this is easy actually. That channel got to like a million subscribers in less than 20 videos, which is crazy because YouTube rewards like if you give them the same thing, they know the transformation they want from that channel. Like the audience knows what they're going to get when they come there. >> Yeah. >> So, it's really important if you want to grow quickly to pick a format. For me, I started out watching YouTube in order to learn things. I was watching finance channels like Graham Stefen. I was watching productivity channels like Ali Abdal. And so, there were a lot of explainer videos. But if you're going to build a educational channel, then we highly recommend some of these formats here. So the first one would be F stands for fixer. My favorite example of the fixer format is the channel Dave Ramsey. He basically has a hotline where people call in and they have financial problems and so he basically helps them fix and talk through their financial problems live. So you could do that with literally any topic that you want. You can have a channel where that fixes like your relationship problems or fixes your I don't know cooking style. You can literally fix anything. Yeah. Whatever knowledge you have, you can demonstrate your expertise through this channel. So, well, >> next one I highly recommend you guys think about is the interview format. So, interview format is amazing if you have unique access to people. So, let's say that you are a doctor, right? you can interview other doctors because you have access to them. >> And it works the same if you are, you know, a lawyer or a nurse or whatever profession you're in, you technically have unique access to that industry. And so if other people want to learn about that industry, then you can bring people in and interview them and you also borrow their expertise. >> Brownie points, I guess, if they're also creators or have their own channel because YouTube has the collab feature now. >> Yeah, that would be great. and you can start collabing with these channels to grow together in your audience and stuff. I think like I saw Ali Abdal recently did this when he brought like Daniel Priestley in and now they have like a collab video and I think he's doing it more often now. >> Um I think that's just going to be something that a lot of channels are going to start doing together to borrow expertise from from other creators to to grow quickly. >> Yeah. >> So there's a bunch of different formats. There's 26 different formats that you can make content around, but it's hard to know like which one you should do. I think a really good place that you kind of teased that is I would start by looking at the competitor landscape in this transformational niche that you want to go into. If everyone in your niche is doing a fixer format and you want to hop into that space, then maybe you shouldn't do a fixer format, at least by itself, maybe you should combine it with uh an explainer or you should do some kind of reaction to something um and give your hot take on it. The best formats that you should do are obviously the ones that you like the most and you think that you're best suited for, but also the things that are not really well represented in the space. So, for example, when we were growing Koi, we had this YouTube series called the ultimate study skills series where we'd help students break down these complex learning skills and and apply them for their own studies. Now, [snorts] most of the other channels in this like getting better grades space focus mainly on just explainers. Not a lot of people yet were taking the a taking it a step further and showing you actually how to implement it with a walkthrough. >> And so we remixed it. We would start off our videos with an explainer talking about why you should use Active Recall, but then we would end the videos, all of those videos with a full walkthrough about how to use it in your actual workflow, >> like step by step. >> Yeah. And we would always have like this overhead shot, I think, with an iPad and like drawing it out or something or some animation in our video to like walk them through us actually using it. And I think that's why those videos got a lot more traction because, you know, people understand what explainers are, but we added something a little bit unique to it, which is walking it through exactly how we did it. And that's why I think the audience really appreciated the value that we gave them. So the second part of content strategy is how often should you post content? And just to keep it as simple as possible, the answer to how often you should post is how often are you able to post consistently? >> Yeah. whatever you're able to do. >> If you want to get into the YouTube game, like you're serious about growing on YouTube, this is by all means an infinite game. >> Like you are not going to stop posting videos. We have been posting videos consistently every single week for what almost 6 years. Yeah. And probably it's going to be for another 6 years. And so I think creator burnout or like burning out from YouTube is probably one of the biggest reasons why people don't stick with it. You know, they try to post too many videos too quickly. They try to pick a format of the video that's like too timeconuming or too difficult to actually stick with and then they burn out. I would say that one of the biggest reasons why creators burn out is they spend too much time and too much effort on their content, especially when they're starting out. So picking a cadence is really important because it kind of helps you gauge how much effort should I be putting into this? If you want to post once a day, then stick to once a day, but find a format that you can actually do once a day. M >> right. If you're going to do like a grand challenge video once a day, that's probably not going to work. But if you pick once a month, that's fine, too. Just do one once a month. Like stay on cadence. It's all about finding what works for you around your lifestyle, what what you can afford to do, and then stick to it, right? Because you said, consistency is the game here. If you are new to content, then there's a lot of learning about how to make better content. And the more pieces of content that you make, the faster you're going to learn about what's good and what's bad for your content. So, I think there's something to be said about focusing more on volume if you're a beginner before you focus on like higher quality stuff. So, I think a great place to start is one video a week. And, you know, a lot of people say that if you really want to give YouTube like an honest shot, you be you should post for at least two years straight. So, do the math there. That means commit yourself right now to making at least 100 videos. You can make 100 videos, that's one video a week for two years. >> And the average channel takes like what 80 uploads to see some kind of traction. >> I think Mr. Beast, you know, listen to the biggest creator in the world. He says your first 100 uploads, you just get out as fast as possible because you just need those reps of learning to get in. And so keep your expectations low if you're just starting out. But if you do have the chops, then you can think about doubling your cadence to get more volume out just to learn faster, especially if you're like trying to switch niches or get into a different space. So 100 ideas, that's actually a great segue into the next piece of YouTube, which is now actually making the content. And the most important piece about content is actually what are your ideas? It's funny, like when you think about making YouTube videos, everyone thinks about the editing. Everyone thinks about the filming of the content. >> Yeah. >> But for YouTube specifically, the most important part about making a video is coming up with the idea for the video. Because YouTube is more like Netflix. It's more like Hollywood than it is like social media because people have to see your thumbnail, your title and thumbnail, and click on it and decide to watch that video. If they don't do that, that one very important step, then it doesn't really matter what you did downstream from that. It doesn't matter how great an edit is. It doesn't matter how long it is. Doesn't matter if you traveled to, I don't know, the Grand Canyon and shot this vlog. If they don't click on it, they're not going to see anything. >> Yeah. It's a click and commit platform. >> Yeah. If if everyone's familiar with the 8020 rule, which I think all of us productivity nerds are, the 8020 rule states that 20% of your efforts equal 80% of your results, which means that 80% of things that you could do don't actually move the needle. And so the things that you should focus on are coming up with good ideas and then titles and thumbnails. So let's talk about like what makes really good ideas for YouTube. So the first thing I would say is like if you are a channel for example, like ours was Koi, how do you get better grades? Mhm. >> We got together one day and we just broke down what are all the different study techniques, what are all the learning principles, what are all the productivity hacks that students would need to get better grades and we just mapped it out. We just drew everything. It's like how to be more productive with um with your calendar, how to time block better, how to use active recall. >> So the first thing I would say is yeah, just map out all of the different topics that you want to make content about. That is the first step. Just see like seeing okay, can you generate ideas on your own for this topic or like for for this space? Because if you can't come up with ideas, um, then maybe you're in the wrong niche. Maybe you have the wrong transformation if you don't really know what you can actually help people achieve. >> Mhm. >> Now, the mistake that creators would make now is just trying to make these ideas as they are. Some of these video ideas might be just super boring. Like, nobody cares about it. The way I think about this is that this is the medicine that they need, but it tastes really nasty, so they don't want to take it. kind of like how like when my daughter got sick, right? We had to give her like some medicine, but it tastes really bad. But when you mix it with something tasty, like with some, you know, some sweet drink or something or like putting in her mashed potatoes or something, >> then she'll be okay. Doesn't notice it and she'll take it and then she'll get the medicine. But that's how you want to think about your audience as well is that you want them to get this knowledge. You want this knowledge to change their life. They need it. But no one's like waking up in the morning and saying like, I want to learn how to use flashcards. So, how do you package this information into something that they want to receive, they want to open, they're excited to open this package and get the knowledge. >> That is the entire game of YouTube. >> The good news is you don't have to guess what a good idea is because there are millions of creators on YouTube that have already figured it Your job is to find those videos, find that evidence. These are videos that we call outlier videos. An outlier video is basically a video that performs better than the average of that channel >> because obviously not every single video on a channel is going to hit. >> Mhm. >> But the ones that do, those ones worked for a reason. So you want to analyze and figure out why those videos worked and kind of borrow ideas, imitate why it worked for your own. I think a great place to start is to go to all again go to all your competitor channels go to their video tab sort by most popular and look at what are the videos that really blew up their channel because odds are like if they've gained you know any traction there's usually just like one or two videos that completely took off for them >> on our channel like for the longest time it was this good notes versus notability video like this video had like half a million views and all the other ones after that had like 30k views or something like that there's always like that one video that blows up and then you get repeat ones and then you know you can add to that bank of it. But most channels that are growing, they'll have just like this one breakout video, this one outlier video. And so your job as a, you know, creator now is to use YouTube and have a different lens on like don't just go to scroll mindlessly. Like study the channels that are in your space. Find out what they're doing well and then try to give your take on what are those popular ideas that they have there. There's this format on YouTube right now that's doing really well that goes, "Give me 10 minutes or a certain amount of minutes and I'll fix something for you or I'll teach you how to be a better learner. Can one of these topics that you want to cover work with this idea?" And that's a way that you can just give it your twist. You don't necessarily have to copy like the exact ideas that they use in this video. That's actually the whole point. You don't want to copy like everything they say in that video because then you're just going to be a copycat. You just want to borrow like what worked for getting the click and then you give your own take on it, >> right? How are we just connecting the right idea to the right psychology? >> So, one thing that we love doing is we use tools to help us rapidly identify these outlier videos. >> So, in your browser, you can download extensions. Um, we use Vid IQ, we use View Stats, and these are free, right? You can just download them and it'll show you an outlier score. >> Mhm. >> So, did the video do 10x better than the average? Did it do a 100x better than the average? Right? If you look hard enough, you can find a 100x videos. >> Yeah, >> those are the videos to look at. What about that video did so well? You want to try to imitate that for your own videos. If you try to like just steal this complete package here, title, thumbnail, and everything about it, your video is going to get destroyed. >> Mhm. >> Why would someone click on your video that has zero views, zero subscribers on the channel versus a video that's got like millions of views from a bigger channel? which is why it's better to just borrow ideas from it and then give it your take. >> And this very thing happened to us actually. So there was a video we had, it was the 2inut video. That video, people actually stole that video and re-uploaded on their channel. And when I went through like the copyright section in our YouTube analytics, there were dozens of channels that literally copied the exact packaging, exact thing. Some of them even had the exact video just changed to a different language >> re-uploaded on their channel. And I will say that none of them broke like a,000 views. >> It just doesn't work. Like if you copy another video, the algorithm is going to show you this 100x versus zero and people are going to go with the 100x every single time. Like there's no way to win when you just completely copy, >> right? This is like the way that we've seen so many of our clients and so many other channels really taking off right now. So, like we said, this is the 20% of the work that's going to get you 80% of the results right here. Kind of paradoxical, kind of backwards to what you might think, but most of your efforts should live here. Coming up with really good ideas and packaging them. So, let's quickly talk about, you know, how do you actually make your videos? The good news now is that, you know, in 2026, all of our devices are just getting better and better. Technology is just getting way better. Like, we just upgraded our phones from to the new iPhone 17 Pros. I might not even need a camera anymore. Like the 4K in this camera, this this phone is so good. Like we could be filming this right now with a camera if we wanted to. I would say for making videos, the two things that you if you want to invest in anything to make high quality videos, number one is a microphone and two is a light. A bigger light with a with a soft box. >> Yeah. >> So a softbox is basically just this cover that goes over the light that diffuses the light so it's not so harsh. It makes these like soft shadows on your face and it just looks very professional. So, in terms of gear, that's all you really need to make good videos. So, now let's move on to actually making your YouTube videos. Now, again, we're like speaking more specifically for like educational content, which usually means you're going to be teaching or helping people solve some kind of problem. And usually, you're going to be talking, >> right? It's either yourself on camera or it's a voiceover or something like that. But, whatever you're going to do, there's going to be some kind of outline or script that you need. We usually outline the videos first just to get the structural ideas out. you know, like maybe like what kind of framework, what are the points that we want to cover, how do they work together, how do they fit together, and then once we have a good outline, then we'll script out a few parts. I don't think you have to script out your whole videos word for word. I know some creators like to do that, but we've been moving more towards this like extemporaneous off-the cuff teaching style because it just feels more natural. One, it makes you come off less robotic, but also scripting word for word takes a long time, especially if you're not a writer. Like we have some clients who spend 5 to 10 hours writing a script >> for like I don't know an 8minute video or something like that. That's a lot of time. >> Yeah, that's too much. That's overthinking even. >> Yeah, that's like way too much time like tweaking some grammar and stuff like that. And so I think you're much better off like getting your ideas out there like outlining the video in terms of like these are the stories that I might want to tell. These are some of the things I want to site. Um and then just letting yourself naturally be on camera because in 2026 right now like with the surge of AI, authenticity is the advantage. If you go to a channel and someone is reading an AI script, like it's pretty obvious. Like I use chatp every single day and I can recognize if someone is reading a chat script. >> The notorious line is I will give you this. No fluff, >> no BS, just plain whatever. Like that is so AI to me. >> Yeah, that one. Or like here's the kicker. >> Yeah, here's the kicker. >> Yeah. Yeah. I think AI is a great outliner. Um, you should use it to outline and you can use it to like revise your writing and stuff, but always try to speak from the heart. I think that's what builds trust more with your audience than anything else. Especially if you're making educational content. I mean, sometimes if you make mistakes, you could also leave it in there if you want to cuz you're just human. It does make everything easier if you plan. Like right now, it feels like we're just kind of talking off the cuff, but we do have an outline right here. like we know the points that we want to hit, but have an outline so that you know the points you want to hit and the points that you don't want to miss. Right? At the end of the day, you're teaching people how to do something for actually editing the videos. That would be a I don't know, a 10-hour video that we'd have to make about how to edit really high quality videos. >> It's so variable, though. Like, you know, every creator on the platform has a different style. Um, a lot of creators even work with outside editors, and I actually highly encourage that you work with editors who know what they're doing, and some editors can do a much better job than you. It's probably a better use of your time to focus here on the uh on the ideas and the and the packaging anyways. But what you absolutely want to do is to create templates every single time you're making a new video. You're not starting from scratch. You're not reinventing the wheel every time. So, for example, there are templates where you can just one-click drag and drop an entire like color grading onto your videos. There's templates for scripting as well. Like, if you have a certain structure to your videos, >> um, we've actually designed like there's hook frameworks and storytelling frameworks. You can figure out everything and kind of lay it out. It makes planning so much easier and it makes the whole process efficient. I mean, that's not something you need to have done by your first video. trying to get all of those like volume so >> that we did this at least for our channel every video that we made we would just make one new template >> you know it's like okay this video the template that I made was this color grading template so the next video I already have that done now let's work on like this animation template where the text pops in now I have two templates you know then the next video you add another one on you know and just keep adding on until you have You don't need a million templates, too, by the way. You just need like, I don't know, just enough to to create this vibe and this style for your content. We've built so many templates over the years. We've built templates for clients. We've built templates for our own channels and stuff. And so, if you're interested in grabbing some of the templates that we've made, these are available to all of the people we work with. Um, links in the description below. Check it out. But now, let's move on to everyone's favorite part about YouTube, how you make money. >> So, to think about this very simply, there are only really two ways that you can make money with YouTube. You can sell your own thing or you can sell someone else's thing. So when it comes to selling your own thing, there are basically three things. You can sell your own products, you can sell your own services, and you can sell experiences. Not to make it more confusing, but each of these three can also be split up into like subcategories. >> For example, for products, you can sell digital products. So, these are like downloadables, templates, um I don't know, any of those like templates we just talked about for video editing and stuff like that. Uh workbooks, ebooks. I think there's a big advantage for educational channels or educational creators to make digital products because the margins are really favorable for you. Or you can sell physical products, things like t-shirts, I don't know, things like uh water bottles, uh notebooks. I've seen some creators selling notebooks, uh matcha. So, for services, there are also two categories. You either can do something for somebody like if someone pays me like hey I want you to >> create a poster for me then you will go and make the poster for them >> or you can do it with them. So hey I want to make a poster I need your help making this poster. So you can guide them you can consult with them. You can coach them you can give them resources to make the poster easier but in general it's done with you or done for you. Yeah. And finally for experiences, I guess there are again two different types of experiences. You can have virtual experiences or you can have inerson experiences. >> So if you look at every single one of these categories, there are millionaires if not billionaires in every single one. So what I'm saying is like they will all work. >> It's just a matter of what do you want to do? What what best fits you? Do you like to say coach people and help them do things or do you want to just build a product and have it done for them and ship it to them? Right? So it it really depends on who you are and what you want to do, what your business is trying to do. >> But at the end of the day, every single one of these things, they help people go through a transformation. So for example, for our channel, the transformation is getting better grades. >> Mhm. >> We have actually tried every single one of these to some extent, right? So we have digital products in terms of templates, courses. >> Mhm. We have physical products in terms of like books or I guess we had some merch. >> Yeah, we stopped doing the merch. >> Yeah, we had like a cozy study hoodie or something. >> So, for services, right, we are in the YouTube education space. >> So, we do have programs where we will coach you and help you grow your YouTube channel and make money from YouTube. But we also have uh an agency side where we just do everything for you. We come up with the ideas, we make the videos, we edit the videos, and we upload it for you. And for experiences, I will say that live events is something that we're shooting for. But we've had plenty of uh online virtual experiences. We've had like uh communities, memberships, we've had, you know, webinars. These are just ways for our community to come together and all learn together and all support each other. of the three over here. I think if you are an educationbased company, there's a really strong argument for starting off in the services category. Specifically for that, I mean like one-on-one something. >> Either that's one-on-one coaching, one-on-one consulting, one-on-one like we'll do the thing for you or do with you. But like you need to get that really intimate hightouch feedback from somebody. Like it's so much faster to help someone by holding their hand and working with them closely than it is to just give them a course and be like, "Hey, have at it." Like figure out on your own. You'll be able to grow your business a lot faster if you start with services. >> Yeah. Cuz at the end of the day, it all comes to getting the people the result, >> getting people the transformation that they want. Like so for us, we did have products where it would teach people how to get better grades. We would put it on the store >> and then people would buy it and they a lot of them would not get better grades, right? None of them would not get the results because it's really up to them to actually take action on what they bought. Like you said, like not only is it going to make your products better and your experiences better, but it's going to make your content better. >> Oh, absolutely. Right? That that's actually probably one of the biggest reasons why services is so good because you learn about what are the problems that my customer actually has. And if you make content about that thing later on and answer the exact questions and pain points they have, you're going to attract so many more people into your business because they're like, "Oh, the content is speaking to the exact problems that I have." All those topics we talked about earlier, like you're not guessing about what those are anymore. Like you know from working with people like what they actually have problems with. And last thing I'll say about pitching services, for services, you can generally charge higher prices than for products and you're investing your time and you're being present with them there. And people will pay a lot more for services. I'm talking about like, you know, in the thousands of dollars for services versus products which can range, you know, from, you know, something like a $5 digital product up to, you know, I think some courses can run to like $1,000 or something like that. But usually those thousand dollar courses have inside of them like other experiences or other like perks and benefits to them, right? Usually it's not just a course anymore. All right, so what about this side? Yeah, let's go to the other side. This one's a little bit simpler. So this was selling your own stuff. On this side, we have selling other people's stuff. And to make this simple as well, there are three categories. First one is AdSense. Next is brand deals, also commonly called sponsorships. And third would be affiliate income. Basically, all three of these are you partnering with some other brand or some other company. >> The first one is easy to understand. This is you partnering with YouTube, right? This is YouTube's partner program. It pays you in AdSense revenue. >> And depending on the niche, your AdSense revenue can be really, really high or really, really low. for example, like yeah, I know the creators in like the finance or the real estate niche, like Graham Stefen, for example, is a big one. They can make so much money from ad revenue because the brands that partner with YouTube that put their ads in your videos are willing to pay you a lot more money. Those are called RPMs, right? How much a brand is willing to pay for that ad spot. >> The [clears throat] finance space and the real estate space, for example, will pay a lot more than for example the study space >> or the productivity or the comedy space. So that's why it's really important to figure out your niche. >> It's also important to note that you won't just start making AdSense revenue from YouTube immediately. There are some requirements to enter the partner program. You need at least I think it's 1,000 subscribers and 4,000 hours of watch time within the past year. So once you hit those numbers, um you can start making AdSense revenue. >> 4,000. It does sound like a lot, >> but some people can get monetized and get the partner program in like a single video if the video gets 4,000 watch hours. Mhm. Yeah. I mean, you can get one video that blows up and then that monetizes your channel. We've had many clients who've just like gotten one video and then suddenly they're monetized and making like 500 bucks. >> So, for these other two ways, this is you partnering with any other brand or company. It doesn't necessarily have to be YouTube. We have partnered with companies like Notion, uh like Amazon, like uh ConvertKit, like Dcript. Um, so whatever companies that match the transformation that you're helping people achieve, you want to think about that ahead of time so that you can build an audience that other companies would want to pay for. >> Mhm. >> So the difference between these two is that for brand deals, a company is sponsoring one of your videos. They will give you money for you to talk about their products in your video. For affiliates, you're basically making a commission every time someone buys something from that company. So, we've had videos where we talk about things like supplements or medical devices, and we kind of compare like which one we think is better. When people buy one of those, then we get a small percentage of that purchase. And again, just like this side, if you look at every single one of these methods, you will find millionaires and potentially billionaires in all of these. So, yes, they all work. But I would say for brand deals, on average, you can earn a lot more compared to AdSense and affiliate. Even in the education space right now, I used to think that like selling your own thing, you can make a lot more money, but there are many educational creators who make a ridiculous amount of money from brand deals. >> Mhm. um because they were able to negotiate brand deals that extend for more than just one video. Some of them even sign like a whole yearly contract with a company. >> It's like every like once a month I'll post a video and they'll give you like a big lumpsum salary almost like you can cover your whole expenses for your whole company year um if you get the right brand deal. >> And so don't sleep on brand deals. Um but again like we said like there's no right or wrong way to make money and you should definitely explore >> multiple of these um to see what works best for your brand and your company. But once you find one that's working, I would definitely like tap into it more. For example, our business, most of our money was made through products and services, right? Like that's where we make the bulk of our money. We have made a lot of brand deal money too, but like we noticed that these levers were working really well and so we invested more effort and energy into making those work better and better. I think there is a mistake of trying to diversify into all of these too quickly >> at the risk, right? It's like if you try to do three things at once, you're not going to do as well as doing one thing really, really well. >> And the reason is because each one of these, they have a different system. If you want to get brand deals all the time, you need to be out there talking to brands, getting in front of them, negotiating with brands, >> building relationships with them, and that is a whole process, right? That takes a lot of time. But on the other hand, if you want to do something like, you know, services, then you need to be out there pitching your idea to customers, getting on sales calls, potentially um evaluating your customers to make sure that they're actually a good fit for your your services, and then actually delivering the services. That also takes a lot of time. I probably just named like three different systems in there or subsystems, >> but as you can see, like these two systems are very different. Mhm. >> And so if you're trying to do all these at the same time and diversify at the same time in the very beginning, we see a lot of creators that fail, they try to diversify too fast at once, they have half built systems and their entire company just falls apart. >> Mhm. >> Now, the one thing that connects all of these together, that sits right in the middle here, and it connects to everything that we talked about in this video, is none of this can work unless you have really good content. >> Right? Content sits at the middle of all of monetization here because if you don't have content, you don't have attention on your channel. You don't have eyeballs that you can monetize, right? No one's going to come buy your products and services. No one's going to give you AdSense money. No brand's going to want to work with you if you don't have good content. And so content unlocks all of this stuff. So again, focus on making this really strong. And then you can also build these things on the back end or use these things if you already have them. Like if you're an established business and you don't have content, then make sure you use that to make good content. Everything also always comes back to the content. >> So if you are struggling with creating content, if you don't have a system or a process to create consistent highquality content, then that's exactly what we specialize in. If you're very serious about approaching YouTube like a proper business, we can help you build out your products, build out your revenue streams, build out an entire system that will make you in and potentially give you more options in life. Maybe you'll find like us that you really really enjoyed the process of making videos. I don't see myself stopping doing this anytime soon. And so I think YouTube as a like career path now, it's something that never existed before. like I actually get to do things that I enjoy every single day and actually make income like a full-time income from it. And so the opportunity has never been better. Like I said, the window is closing. I know we covered everything really, really fast in this video, but if you want like a full deep dive, like a threehour masterass video into our entire YouTube system, then definitely check out this video right here. It's going to be everything you wanted and

## Segments

| Time | Duration | Text |
|------|----------|------|
| 0:00 | 3.3s | If I lost my YouTube channel tomorrow |
| 0:01 | 3.4s | and had to start over, I'd do it very |
| 0:03 | 3.1s | differently because what's working now |
| 0:04 | 3.3s | is completely different from what's |
| 0:06 | 2.9s | working even a year ago. So, in this |
| 0:08 | 3.0s | video, we're going to take you through |
| 0:09 | 4.1s | the last 6 years of [music] building a |
| 0:11 | 3.7s | YouTube channel to over 1.3 million |
| 0:13 | 3.6s | subscribers. We're going to give you a |
| 0:14 | 3.8s | clear road map on how to build a YouTube |
| 0:17 | 3.6s | [music] channel that generates income |
| 0:18 | 4.2s | and could potentially replace your day |
| 0:20 | 3.9s | job. Well, before we get to the actual |
| 0:22 | 3.3s | steps, I think there's one very |
| 0:24 | 2.9s | important question that everyone needs |
| 0:26 | 2.3s | to answer before they start a YouTube |
| 0:27 | 2.2s | channel. Why do you want to build a |
| 0:28 | 2.5s | YouTube channel in the first place? Do |
| 0:29 | 2.7s | you want to be famous? Do you want to |
| 0:30 | 2.9s | get a lot of views? Do you want to make |
| 0:32 | 2.9s | money? Or do you want to just have a |
| 0:33 | 2.6s | side project for fun? Because if you |
| 0:35 | 2.3s | don't really know what you're going to |
| 0:36 | 1.8s | build, you're going to end up building |
| 0:37 | 2.8s | the wrong thing. |
| 0:38 | 4.3s | >> And we've seen out there that you can |
| 0:40 | 4.0s | have a lot of subscribers, but not a lot |
| 0:42 | 3.4s | of money. And the other way around, you |
| 0:44 | 3.5s | can have not very many subscribers and |
| 0:46 | 2.8s | still make a great amount of money. |
| 0:47 | 2.2s | >> So, we've worked with dozens of |
| 0:48 | 3.4s | creators. We've studied thousands of |
| 0:50 | 4.0s | YouTube videos. And there are only three |
| 0:52 | 3.8s | types of channels that consistently work |
| 0:54 | 4.1s | on YouTube. The first type of channel |
| 0:56 | 4.7s | are the entertainment channels, right? |
| 0:58 | 5.0s | Think about Mr. Beast, any gaming |
| 1:00 | 4.3s | channel, reaction channels, |
| 1:03 | 4.0s | >> skits. So, the second type of channel is |
| 1:05 | 5.0s | the educational channel. And this type |
| 1:07 | 5.4s | of channel is not to be confused with |
| 1:10 | 5.5s | like Con Academy or like a study type of |
| 1:12 | 4.6s | channel, right? This is a channel that |
| 1:15 | 3.2s | people go to to learn, |
| 1:17 | 3.8s | >> right? Because at the end of the day, |
| 1:18 | 4.2s | YouTube is a search platform where |
| 1:21 | 3.8s | people go and type in their questions if |
| 1:22 | 4.2s | they have problems that they need |
| 1:24 | 4.1s | answers to. So you can learn anything |
| 1:27 | 4.0s | from YouTube nowadays, YouTube |
| 1:29 | 4.5s | University. So a few examples here. Of |
| 1:31 | 4.7s | course, our channel, we teach YouTube, |
| 1:33 | 5.1s | but one of my favorite niches is |
| 1:35 | 5.8s | business education. So people like Alex |
| 1:38 | 4.8s | Herozi, Leila Heroszi, Cody Sanchez, but |
| 1:41 | 3.4s | really you can learn about anything you |
| 1:43 | 3.1s | want. Just name it, search it, and |
| 1:44 | 3.3s | you'll probably find the most niche |
| 1:46 | 3.3s | educational content. The third type of |
| 1:48 | 3.5s | channel is an empowerment channel. |
| 1:49 | 4.9s | Empowerment channels are channels that |
| 1:51 | 5.5s | are focused on good vibes or relaxation |
| 1:54 | 4.5s | or motivation. Examples of these, the |
| 1:57 | 3.3s | biggest example is like what chill cow |
| 1:59 | 3.3s | or uh I love that. |
| 2:00 | 5.0s | >> Chillhop radio, stuff like that. Or like |
| 2:02 | 4.2s | any circle I do like music sets, |
| 2:05 | 2.7s | >> boiler room, that's a good example of |
| 2:06 | 3.8s | it. Study with me, that's a big one, |
| 2:08 | 3.8s | too. Work with me, 8 hours of stoicism |
| 2:10 | 3.0s | to fall asleep to, you know, like these |
| 2:12 | 3.0s | long channels that are just meant for |
| 2:13 | 3.1s | vibes or just like good scenery and |
| 2:15 | 3.0s | background. So these are the three |
| 2:16 | 3.8s | channels that you can make. Again, |
| 2:18 | 3.4s | there's no wrong channel you can pick. |
| 2:20 | 2.4s | It's just asking the question like, |
| 2:21 | 2.6s | "What kind of channel do I want to |
| 2:22 | 3.0s | build?" So you don't accidentally build |
| 2:24 | 4.4s | something that you don't want to build. |
| 2:25 | 4.2s | Now, of these three channels though, our |
| 2:28 | 3.4s | favorite type of channel and the channel |
| 2:30 | 3.9s | that we believe is going to be like the |
| 2:31 | 4.5s | the ones with the most leverage for the |
| 2:33 | 2.7s | future are the educational channels. |
| 2:36 | 2.5s | >> Mhm. [clears throat] |
| 2:36 | 4.2s | >> These are channels that specifically |
| 2:38 | 2.8s | help people solve some kind of problem. |
| 2:40 | 2.3s | This is something I learned about |
| 2:41 | 4.0s | YouTube a few years into our YouTube |
| 2:43 | 4.6s | journey. YouTube is a business and |
| 2:45 | 4.3s | businesses solve problems and businesses |
| 2:47 | 4.1s | make money. So those two things go hand |
| 2:50 | 3.8s | in hand. And so if we're trying to build |
| 2:51 | 3.9s | a YouTube channel that makes money, then |
| 2:53 | 4.0s | an educational channel has the highest |
| 2:55 | 5.0s | upside. I think in 2026, an educational |
| 2:57 | 4.1s | channel has the like outsiz returns |
| 3:00 | 4.1s | >> compared to these other channels. |
| 3:01 | 6.3s | >> I'll also say that the vast majority of |
| 3:04 | 6.8s | YouTube content is entertainment. So |
| 3:08 | 6.6s | what that means is that there is a big |
| 3:11 | 5.3s | gap in educational content. We need more |
| 3:14 | 4.1s | of that. If you have something to teach |
| 3:16 | 4.0s | and you have problems to solve, then |
| 3:18 | 3.3s | there's not as much competition as if |
| 3:20 | 1.8s | you were to make an entertainment |
| 3:22 | 2.1s | channel, |
| 3:22 | 3.7s | >> right? And it might feel like, you know, |
| 3:24 | 3.4s | there are so many creators joining the |
| 3:26 | 3.1s | game right now, but you were still |
| 3:27 | 3.9s | pretty early. But that window is closing |
| 3:29 | 3.3s | because of AI and how quickly you can |
| 3:31 | 3.8s | start to build a channel and grow |
| 3:32 | 5.4s | something quickly. So, if you ever want |
| 3:35 | 4.9s | to start a YouTube channel, like 2026 is |
| 3:38 | 3.5s | a great time and potentially like one of |
| 3:40 | 3.4s | the last years when it might be quote |
| 3:41 | 4.0s | unquote easy to blow up on social media. |
| 3:43 | 4.0s | >> And the educational type of content |
| 3:45 | 4.2s | holds a special place in my heart. Way |
| 3:47 | 5.4s | back when we first started YouTube, we |
| 3:49 | 5.8s | were looking for a way to actually use |
| 3:52 | 5.4s | what we already had. So, we already had |
| 3:55 | 4.2s | knowledge from 10 years of studying to |
| 3:58 | 3.6s | become doctors. That's what we were |
| 3:59 | 4.5s | before we did all this stuff. And |
| 4:01 | 5.0s | actually, YouTube allowed us to quit our |
| 4:04 | 5.5s | jobs as doctors because of the ability |
| 4:06 | 5.2s | for us to teach online and reach way |
| 4:09 | 4.1s | more people than we ever could have as |
| 4:12 | 4.6s | doctors. When we went full-time into |
| 4:13 | 5.7s | YouTube, I was like in my early 30s. And |
| 4:16 | 5.2s | to me, I felt that sense of urgency |
| 4:19 | 4.5s | because I wanted to start a family soon |
| 4:21 | 4.4s | and I didn't want to spend the next 10 |
| 4:24 | 4.6s | years of my life building a business |
| 4:26 | 3.8s | from scratch. So using our knowledge and |
| 4:28 | 2.7s | starting from there was actually the |
| 4:30 | 3.5s | highest leverage point that we could |
| 4:31 | 4.7s | have done. So that is the reason why we |
| 4:33 | 4.2s | chose educational channel of all these |
| 4:36 | 3.1s | three. So for the rest of this video, |
| 4:37 | 4.1s | we're going to be talking specifically |
| 4:39 | 3.8s | about educational channel because we |
| 4:42 | 3.4s | think that that's the greatest |
| 4:43 | 3.7s | opportunity. But just know that the |
| 4:45 | 3.4s | lessons that we teach here, they're |
| 4:46 | 3.3s | going to apply to every single kind. So |
| 4:48 | 2.9s | now that we know what kind of channel |
| 4:50 | 3.8s | we're looking to build, the next |
| 4:51 | 5.2s | question is what type of content should |
| 4:53 | 4.4s | we make? aka when everyone says, "What's |
| 4:56 | 2.6s | the niche we should pick for our |
| 4:58 | 3.0s | channel?" Honestly, the longer I've been |
| 4:59 | 3.3s | on YouTube, the more I think that's the |
| 5:01 | 2.9s | wrong question to ask. I think a much |
| 5:02 | 3.1s | better question is, "What is the |
| 5:04 | 3.4s | transformation that you want your viewer |
| 5:05 | 4.8s | to have from watching your content?" |
| 5:07 | 6.0s | Because it really targets a person, your |
| 5:10 | 6.1s | target audience, instead of like just a |
| 5:13 | 4.2s | general general ambiguous term, right? |
| 5:16 | 3.5s | >> Yeah. Yeah, I mean if you want to think |
| 5:17 | 4.3s | about it very simply, you're defining |
| 5:20 | 4.5s | who is watching your videos |
| 5:22 | 4.0s | >> and you're defining why they're watching |
| 5:24 | 3.8s | your videos. But the word |
| 5:26 | 5.0s | transformation, it also implies that |
| 5:28 | 3.2s | people are going to be impacted by your |
| 5:31 | 1.9s | content, |
| 5:31 | 3.8s | >> right? Their lives are going to change |
| 5:32 | 4.5s | in some way. And as creators, that's |
| 5:35 | 3.8s | what we ultimately want, right? We want |
| 5:37 | 3.0s | our content to have meaning, to have |
| 5:39 | 2.6s | impact on people. |
| 5:40 | 3.0s | >> So let's do a few examples about like |
| 5:41 | 3.0s | what's the difference between a niche |
| 5:43 | 2.4s | and a transformation, just so it's like |
| 5:44 | 2.6s | super clear. |
| 5:45 | 3.4s | >> Okay. Um, let's start with our channel |
| 5:47 | 3.1s | as an example. So, when we were growing |
| 5:49 | 3.2s | our channel Koi for the beginning, we |
| 5:50 | 5.0s | thought the channel was a study channel, |
| 5:52 | 4.8s | but study is a pretty general term. |
| 5:55 | 3.8s | There's a lot of different content that |
| 5:57 | 4.4s | can be for study. So, you can have |
| 5:59 | 3.8s | channels where they teach you how to |
| 6:01 | 4.0s | study, like the study techniques and |
| 6:03 | 4.2s | strategies. You can have a study with me |
| 6:05 | 3.1s | channel where the person probably |
| 6:07 | 2.4s | doesn't even say anything. They're just |
| 6:08 | 3.4s | sitting there and studying. |
| 6:09 | 3.4s | >> There's like study vlog channels where |
| 6:12 | 3.4s | no face and they just walk around. This |
| 6:13 | 4.2s | is my day as a student. So, we went from |
| 6:15 | 3.6s | just a study channel to our |
| 6:17 | 3.2s | transformation being we're going to help |
| 6:19 | 3.1s | students get better grades through |
| 6:20 | 3.4s | evidence-based learning skills. |
| 6:22 | 5.6s | >> And real quickly, let's just draw a |
| 6:24 | 6.3s | visual for what actually is a |
| 6:27 | 5.7s | transformation. So, transformation is |
| 6:30 | 6.9s | you're helping take someone from a point |
| 6:33 | 6.2s | A to a point B. |
| 6:37 | 3.1s | >> Like that's the most simplest terms we |
| 6:39 | 4.2s | can say it, |
| 6:40 | 5.4s | >> right? So, you go from sad to happy. you |
| 6:43 | 3.0s | go from poor to rich. |
| 6:45 | 3.6s | >> So, if you've been watching this |
| 6:46 | 4.7s | channel, we are evolving because the |
| 6:49 | 3.7s | world has gotten a little bit crazy and |
| 6:51 | 3.5s | we don't really believe that getting |
| 6:53 | 3.0s | better grades is a the ultimate |
| 6:55 | 2.5s | transformation that you should be |
| 6:56 | 3.1s | shooting for. I think that learning |
| 6:57 | 3.9s | skills is really important, but what you |
| 6:59 | 3.8s | do with those skills now is not just to |
| 7:01 | 3.1s | get better grades, it's to build |
| 7:02 | 3.4s | self-reliance. It's to get better paying |
| 7:04 | 3.6s | work because you can't really rely on |
| 7:06 | 3.6s | grades and degrees to get you good jobs |
| 7:08 | 3.4s | anymore. And we're entering what you |
| 7:09 | 2.8s | would call the business niche. But |
| 7:11 | 3.0s | business again, like if you write |
| 7:12 | 3.4s | business down on the niche side, there's |
| 7:14 | 3.5s | so much types of business content out |
| 7:16 | 3.9s | there. Manufacturing businesses, there's |
| 7:18 | 2.4s | online business, there's creator economy |
| 7:20 | 1.5s | business, |
| 7:20 | 2.3s | >> there's Shark Tank. |
| 7:21 | 3.0s | >> There's Shark Tank. |
| 7:22 | 3.4s | >> Yeah. Well, like if you say business |
| 7:24 | 3.8s | content, it's not really clear like, |
| 7:26 | 4.2s | okay, what kind of business content am I |
| 7:28 | 3.0s | making? So, our transformation right |
| 7:30 | 3.4s | now, what would you say it is? |
| 7:31 | 3.0s | >> Yeah. I would say it's make money with |
| 7:33 | 1.0s | YouTube. |
| 7:34 | 3.2s | >> Mhm. |
| 7:34 | 4.4s | >> So, you're starting from point A. I have |
| 7:37 | 3.1s | a YouTube channel that doesn't really |
| 7:39 | 3.2s | make me much income. |
| 7:40 | 3.8s | >> Mhm. to point B. I have a YouTube |
| 7:42 | 4.9s | channel that does make me income |
| 7:44 | 6.2s | >> and then all the, you know, perks and |
| 7:47 | 5.1s | benefits that comes with a profitable |
| 7:50 | 3.9s | YouTube channel. So, the whole point of |
| 7:52 | 5.7s | shifting from niche transformation is to |
| 7:54 | 6.3s | really help the target viewer know, is |
| 7:58 | 5.5s | this channel for me? Did this creator |
| 8:00 | 4.9s | make content that I actually want to |
| 8:03 | 3.5s | watch? In fact, like if you focus on a |
| 8:05 | 3.3s | transformation, you're actually going to |
| 8:07 | 3.8s | grow your channel a lot faster, too. |
| 8:09 | 3.3s | Because going from niche to |
| 8:10 | 3.4s | transformation, this is what the YouTube |
| 8:12 | 3.8s | algorithm is is trying to do every |
| 8:14 | 3.6s | single day when it matches content to |
| 8:16 | 3.8s | you. In the past, you would see channels |
| 8:17 | 3.9s | on your homepage from creators that you |
| 8:20 | 3.4s | actually subscribe to. Nowadays, that's |
| 8:21 | 3.1s | flipped. There's a lot of pros and cons |
| 8:23 | 2.6s | in that. Obviously, if you're a new |
| 8:24 | 3.0s | creator, you're a new channel, then |
| 8:26 | 3.4s | YouTube is actively helping these |
| 8:27 | 3.3s | channels grow and get some viewership. |
| 8:29 | 3.4s | If you don't make content that is very |
| 8:31 | 3.2s | specific for transformation, then you're |
| 8:32 | 2.8s | not going to get your content promoted. |
| 8:34 | 3.2s | I think a lot of channels that used to |
| 8:35 | 3.8s | make content that was all over the place |
| 8:37 | 3.0s | are seeing a huge drop in viewership. |
| 8:39 | 2.6s | That's kind of what happened on our |
| 8:40 | 3.0s | channel Koi for a little bit too and we |
| 8:42 | 4.0s | tried to switch the transformation too |
| 8:43 | 4.7s | quickly and it didn't really reward us. |
| 8:46 | 5.0s | >> What you said before there is also very |
| 8:48 | 6.0s | important especially for this year is |
| 8:51 | 4.9s | that you're seeing just regular people |
| 8:54 | 3.0s | like normal people blowing up on |
| 8:55 | 2.6s | YouTube. Like I don't know how many |
| 8:57 | 4.1s | you've seen like when you're scrolling |
| 8:58 | 5.8s | through your phone. I have seen channels |
| 9:01 | 4.5s | that have like hundreds of subscribers. |
| 9:04 | 2.2s | I've seen videos that have like 20 |
| 9:05 | 1.1s | views. |
| 9:06 | 2.8s | >> Yeah. |
| 9:07 | 3.6s | >> The thing is that those videos that are |
| 9:09 | 3.4s | recommended to me, |
| 9:10 | 3.7s | >> they are on the exact topics that I was |
| 9:12 | 3.2s | watching like yesterday or like I was |
| 9:14 | 3.4s | watching an hour ago. |
| 9:15 | 3.0s | >> Sometimes I will give those videos a |
| 9:17 | 1.6s | chance [laughter] |
| 9:18 | 2.2s | >> sometimes |
| 9:19 | 2.7s | >> and I will click on them and they are |
| 9:21 | 3.0s | terrible. |
| 9:22 | 3.2s | >> But other times I have found some gems |
| 9:24 | 3.2s | of a channel |
| 9:25 | 4.3s | >> and I was thankful that it was served to |
| 9:27 | 4.4s | me. The only thing that matters is can |
| 9:29 | 2.6s | you make just really really really good |
| 9:31 | 0.8s | content. |
| 9:32 | 1.8s | >> Yeah. |
| 9:32 | 2.7s | >> If you can do that, then you will blow |
| 9:33 | 3.1s | up. Like it's that simple. |
| 9:35 | 3.7s | >> People say you blow up quote unquote |
| 9:37 | 3.2s | overnight, but that's not actually the |
| 9:38 | 3.6s | case. So I discovered this channel |
| 9:40 | 3.9s | called Superordinary. And when I found |
| 9:42 | 3.6s | him, he had like a hundred subs or |
| 9:44 | 4.2s | something and his videos had like barely |
| 9:46 | 5.4s | any views. But when I watched it, it was |
| 9:48 | 5.6s | like a cinematic masterpiece. And I was |
| 9:51 | 5.1s | like, "This guy is going to blow up |
| 9:53 | 4.6s | overnight." But he had spent probably 10 |
| 9:56 | 4.5s | years of his life before that working on |
| 9:58 | 4.3s | these skills being able to create such |
| 10:01 | 4.4s | cinematic masterpieces. |
| 10:02 | 5.7s | >> So if you already have knowledge that |
| 10:05 | 5.3s | you have acred for years, a diploma that |
| 10:08 | 3.8s | took you so many years to get, then you |
| 10:10 | 3.4s | can blow up overnight. When you speak |
| 10:12 | 3.9s | with confidence on what you're teaching, |
| 10:14 | 3.3s | people can see that authority right away |
| 10:16 | 2.6s | >> and they will follow you. |
| 10:17 | 2.6s | >> I mean, honestly, like when creators |
| 10:18 | 2.8s | come to us and say, "Hey, I want to |
| 10:20 | 3.0s | start a channel, but I don't know what I |
| 10:21 | 2.9s | should make content about." this is the |
| 10:23 | 3.0s | exact question that they're stumped with |
| 10:24 | 3.4s | and most people quit right here because |
| 10:26 | 3.2s | they just get stuck in analysis |
| 10:27 | 2.6s | paralysis of not knowing what kind of |
| 10:29 | 2.0s | content to make and then just never |
| 10:30 | 2.7s | making content. |
| 10:31 | 5.0s | >> You can check out our free tool. We |
| 10:33 | 4.6s | actually have a lot of frameworks on how |
| 10:36 | 4.0s | to figure this out. It does the thinking |
| 10:37 | 3.1s | for you. So check out that free tool |
| 10:40 | 2.2s | link in the description. |
| 10:40 | 2.8s | >> So now that we've picked the |
| 10:42 | 3.4s | transformation that we want our channel |
| 10:43 | 4.4s | to accomplish, it's now time to move on |
| 10:45 | 3.9s | to the content strategy for growing on |
| 10:48 | 4.2s | YouTube. How often should I post that |
| 10:49 | 4.7s | content? So, if you've been watching any |
| 10:52 | 4.0s | YouTube at all, then that's probably |
| 10:54 | 3.5s | going to kind of sway you and give you |
| 10:56 | 3.8s | clues on what content you might want to |
| 10:58 | 5.4s | try because there's a lot of different |
| 11:00 | 5.1s | what we call formats to making YouTube |
| 11:03 | 3.8s | videos. Format is basically just a |
| 11:05 | 4.2s | structure on how you make your videos. |
| 11:07 | 5.4s | So, the reason we want to pick a format |
| 11:09 | 5.3s | is because YouTube really rewards |
| 11:12 | 4.0s | channels that give their audience the |
| 11:14 | 3.4s | same thing over and over and over, |
| 11:16 | 3.5s | right? I'll I'll give an example of what |
| 11:18 | 3.6s | I mean by this. So, I think a couple |
| 11:20 | 4.4s | years ago, maybe it was last year, there |
| 11:21 | 4.8s | was this channel that blew up called |
| 11:24 | 3.7s | Easy Actually. The first video that he |
| 11:26 | 3.8s | posted on the channel that blew up was |
| 11:28 | 3.8s | becoming smart is easy actually. And |
| 11:30 | 3.8s | then the next video he posted was like |
| 11:31 | 3.4s | losing weight is easy actually. And he |
| 11:34 | 4.2s | just kept following up everything over |
| 11:35 | 5.1s | and over using the same exact format of |
| 11:38 | 3.3s | like doing this is easy actually. That |
| 11:40 | 3.4s | channel got to like a million |
| 11:41 | 4.7s | subscribers in less than 20 videos, |
| 11:43 | 3.9s | which is crazy because YouTube rewards |
| 11:46 | 2.7s | like if you give them the same thing, |
| 11:47 | 2.6s | they know the transformation they want |
| 11:48 | 2.3s | from that channel. Like the audience |
| 11:50 | 1.6s | knows what they're going to get when |
| 11:51 | 1.0s | they come there. |
| 11:51 | 2.2s | >> Yeah. |
| 11:52 | 4.5s | >> So, it's really important if you want to |
| 11:54 | 4.7s | grow quickly to pick a format. For me, I |
| 11:56 | 4.5s | started out watching YouTube in order to |
| 11:58 | 4.5s | learn things. I was watching finance |
| 12:01 | 3.7s | channels like Graham Stefen. I was |
| 12:03 | 4.2s | watching productivity channels like Ali |
| 12:04 | 4.6s | Abdal. And so, there were a lot of |
| 12:07 | 6.2s | explainer videos. But if you're going to |
| 12:09 | 6.2s | build a educational channel, then we |
| 12:13 | 5.0s | highly recommend some of these formats |
| 12:15 | 5.2s | here. So the first one would be F stands |
| 12:18 | 5.3s | for fixer. My favorite example of the |
| 12:20 | 4.4s | fixer format is the channel Dave Ramsey. |
| 12:23 | 5.3s | He basically has a hotline where people |
| 12:25 | 6.2s | call in and they have financial problems |
| 12:29 | 4.0s | and so he basically helps them fix and |
| 12:31 | 3.3s | talk through their financial problems |
| 12:33 | 4.4s | live. So you could do that with |
| 12:34 | 4.9s | literally any topic that you want. You |
| 12:37 | 5.5s | can have a channel where that fixes like |
| 12:39 | 5.3s | your relationship problems or fixes your |
| 12:43 | 3.8s | I don't know cooking style. You can |
| 12:45 | 4.6s | literally fix anything. Yeah. Whatever |
| 12:46 | 5.2s | knowledge you have, you can demonstrate |
| 12:49 | 3.2s | your expertise through this channel. So, |
| 12:52 | 2.7s | well, |
| 12:52 | 5.0s | >> next one I highly recommend you guys |
| 12:54 | 5.4s | think about is the interview format. So, |
| 12:57 | 5.0s | interview format is amazing if you have |
| 13:00 | 6.6s | unique access to people. So, let's say |
| 13:02 | 5.8s | that you are a doctor, right? you can |
| 13:06 | 3.3s | interview other doctors because you have |
| 13:08 | 3.4s | access to them. |
| 13:10 | 4.4s | >> And it works the same if you are, you |
| 13:12 | 4.2s | know, a lawyer or a nurse or whatever |
| 13:14 | 4.5s | profession you're in, you technically |
| 13:16 | 4.0s | have unique access to that industry. And |
| 13:18 | 3.4s | so if other people want to learn about |
| 13:20 | 3.7s | that industry, then you can bring people |
| 13:22 | 3.4s | in and interview them and you also |
| 13:24 | 3.1s | borrow their expertise. |
| 13:25 | 3.0s | >> Brownie points, I guess, if they're also |
| 13:27 | 3.0s | creators or have their own channel |
| 13:28 | 2.0s | because YouTube has the collab feature |
| 13:30 | 1.6s | now. |
| 13:30 | 3.1s | >> Yeah, that would be great. and you can |
| 13:31 | 3.5s | start collabing with these channels to |
| 13:33 | 3.4s | grow together in your audience and |
| 13:35 | 3.5s | stuff. I think like I saw Ali Abdal |
| 13:37 | 3.0s | recently did this when he brought like |
| 13:38 | 2.6s | Daniel Priestley in and now they have |
| 13:40 | 2.4s | like a collab video and I think he's |
| 13:41 | 2.3s | doing it more often now. |
| 13:42 | 2.2s | >> Um I think that's just going to be |
| 13:43 | 2.8s | something that a lot of channels are |
| 13:44 | 4.0s | going to start doing together to borrow |
| 13:46 | 2.9s | expertise from from other creators to to |
| 13:48 | 1.0s | grow quickly. |
| 13:49 | 1.9s | >> Yeah. |
| 13:49 | 3.4s | >> So there's a bunch of different formats. |
| 13:51 | 3.3s | There's 26 different formats that you |
| 13:53 | 3.6s | can make content around, but it's hard |
| 13:54 | 3.9s | to know like which one you should do. I |
| 13:56 | 3.8s | think a really good place that you kind |
| 13:58 | 4.1s | of teased that is I would start by |
| 14:00 | 3.5s | looking at the competitor landscape in |
| 14:02 | 3.4s | this transformational niche that you |
| 14:04 | 4.5s | want to go into. If everyone in your |
| 14:06 | 4.1s | niche is doing a fixer format and you |
| 14:08 | 3.1s | want to hop into that space, then maybe |
| 14:10 | 3.2s | you shouldn't do a fixer format, at |
| 14:11 | 4.8s | least by itself, maybe you should |
| 14:13 | 5.9s | combine it with uh an explainer or you |
| 14:16 | 5.0s | should do some kind of reaction to |
| 14:19 | 3.6s | something um and give your hot take on |
| 14:21 | 2.6s | it. The best formats that you should do |
| 14:22 | 2.3s | are obviously the ones that you like the |
| 14:24 | 3.0s | most and you think that you're best |
| 14:25 | 3.3s | suited for, but also the things that are |
| 14:27 | 3.0s | not really well represented in the |
| 14:28 | 3.7s | space. So, for example, when we were |
| 14:30 | 3.8s | growing Koi, we had this YouTube series |
| 14:32 | 3.2s | called the ultimate study skills series |
| 14:33 | 3.3s | where we'd help students break down |
| 14:35 | 3.7s | these complex learning skills and and |
| 14:37 | 3.4s | apply them for their own studies. Now, |
| 14:39 | 4.3s | [snorts] most of the other channels in |
| 14:40 | 5.2s | this like getting better grades space |
| 14:43 | 5.0s | focus mainly on just explainers. Not a |
| 14:45 | 4.2s | lot of people yet were taking the a |
| 14:48 | 3.7s | taking it a step further and showing you |
| 14:49 | 3.0s | actually how to implement it with a |
| 14:52 | 2.8s | walkthrough. |
| 14:52 | 3.6s | >> And so we remixed it. We would start off |
| 14:54 | 3.8s | our videos with an explainer talking |
| 14:56 | 4.2s | about why you should use Active Recall, |
| 14:58 | 3.4s | but then we would end the videos, all of |
| 15:00 | 3.0s | those videos with a full walkthrough |
| 15:02 | 2.1s | about how to use it in your actual |
| 15:03 | 1.4s | workflow, |
| 15:04 | 2.3s | >> like step by step. |
| 15:05 | 3.0s | >> Yeah. And we would always have like this |
| 15:06 | 3.4s | overhead shot, I think, with an iPad and |
| 15:08 | 3.7s | like drawing it out or something or some |
| 15:09 | 3.8s | animation in our video to like walk them |
| 15:11 | 3.4s | through us actually using it. And I |
| 15:13 | 3.0s | think that's why those videos got a lot |
| 15:15 | 3.5s | more traction because, you know, people |
| 15:16 | 3.4s | understand what explainers are, but we |
| 15:18 | 3.4s | added something a little bit unique to |
| 15:20 | 3.2s | it, which is walking it through exactly |
| 15:22 | 2.8s | how we did it. And that's why I think |
| 15:23 | 2.7s | the audience really appreciated the |
| 15:24 | 3.3s | value that we gave them. So the second |
| 15:26 | 4.1s | part of content strategy is how often |
| 15:28 | 4.0s | should you post content? And just to |
| 15:30 | 3.8s | keep it as simple as possible, the |
| 15:32 | 4.2s | answer to how often you should post is |
| 15:33 | 3.0s | how often are you able to post |
| 15:36 | 2.1s | consistently? |
| 15:36 | 2.6s | >> Yeah. whatever you're able to do. |
| 15:38 | 2.9s | >> If you want to get into the YouTube |
| 15:39 | 4.7s | game, like you're serious about growing |
| 15:41 | 4.2s | on YouTube, this is by all means an |
| 15:44 | 2.7s | infinite game. |
| 15:45 | 3.5s | >> Like you are not going to stop posting |
| 15:47 | 4.6s | videos. We have been posting videos |
| 15:48 | 4.6s | consistently every single week for what |
| 15:51 | 4.5s | almost 6 years. Yeah. And probably it's |
| 15:53 | 4.9s | going to be for another 6 years. And so |
| 15:56 | 3.5s | I think creator burnout or like burning |
| 15:58 | 2.7s | out from YouTube is probably one of the |
| 15:59 | 3.2s | biggest reasons why people don't stick |
| 16:01 | 3.3s | with it. You know, they try to post too |
| 16:02 | 3.4s | many videos too quickly. They try to |
| 16:04 | 4.2s | pick a format of the video that's like |
| 16:06 | 3.8s | too timeconuming or too difficult to |
| 16:08 | 3.8s | actually stick with and then they burn |
| 16:10 | 4.6s | out. I would say that one of the biggest |
| 16:12 | 5.0s | reasons why creators burn out is they |
| 16:14 | 4.5s | spend too much time and too much effort |
| 16:17 | 3.7s | on their content, especially when |
| 16:19 | 3.4s | they're starting out. So picking a |
| 16:21 | 4.4s | cadence is really important because it |
| 16:22 | 4.3s | kind of helps you gauge how much effort |
| 16:25 | 4.2s | should I be putting into this? If you |
| 16:27 | 5.0s | want to post once a day, then stick to |
| 16:29 | 4.1s | once a day, but find a format that you |
| 16:32 | 3.0s | can actually do once a day. M |
| 16:33 | 4.6s | >> right. If you're going to do like a |
| 16:35 | 5.0s | grand challenge video once a day, that's |
| 16:38 | 4.2s | probably not going to work. But if you |
| 16:40 | 5.0s | pick once a month, that's fine, too. |
| 16:42 | 5.3s | Just do one once a month. Like stay on |
| 16:45 | 5.4s | cadence. It's all about finding what |
| 16:47 | 4.8s | works for you around your lifestyle, |
| 16:50 | 3.8s | what what you can afford to do, and then |
| 16:52 | 3.3s | stick to it, right? Because you said, |
| 16:54 | 3.3s | consistency is the game here. If you are |
| 16:55 | 3.0s | new to content, then there's a lot of |
| 16:57 | 3.3s | learning about how to make better |
| 16:58 | 3.4s | content. And the more pieces of content |
| 17:00 | 3.4s | that you make, the faster you're going |
| 17:02 | 3.7s | to learn about what's good and what's |
| 17:04 | 3.4s | bad for your content. So, I think |
| 17:05 | 3.2s | there's something to be said about |
| 17:07 | 4.5s | focusing more on volume if you're a |
| 17:09 | 5.0s | beginner before you focus on like higher |
| 17:12 | 4.9s | quality stuff. So, I think a great place |
| 17:14 | 4.0s | to start is one video a week. And, you |
| 17:16 | 2.5s | know, a lot of people say that if you |
| 17:18 | 3.4s | really want to give YouTube like an |
| 17:19 | 4.5s | honest shot, you be you should post for |
| 17:21 | 4.2s | at least two years straight. So, do the |
| 17:23 | 3.9s | math there. That means commit yourself |
| 17:25 | 3.4s | right now to making at least 100 videos. |
| 17:27 | 2.4s | You can make 100 videos, that's one |
| 17:29 | 3.4s | video a week for two years. |
| 17:30 | 4.7s | >> And the average channel takes like what |
| 17:32 | 4.0s | 80 uploads to see some kind of traction. |
| 17:34 | 3.0s | >> I think Mr. Beast, you know, listen to |
| 17:36 | 2.9s | the biggest creator in the world. He |
| 17:37 | 3.4s | says your first 100 uploads, you just |
| 17:39 | 3.5s | get out as fast as possible because you |
| 17:41 | 4.3s | just need those reps of learning to get |
| 17:42 | 4.6s | in. And so keep your expectations low if |
| 17:45 | 3.7s | you're just starting out. But if you do |
| 17:47 | 3.5s | have the chops, then you can think about |
| 17:49 | 3.4s | doubling your cadence to get more volume |
| 17:50 | 3.5s | out just to learn faster, especially if |
| 17:52 | 4.4s | you're like trying to switch niches or |
| 17:54 | 4.6s | get into a different space. So 100 |
| 17:56 | 5.7s | ideas, that's actually a great segue |
| 17:59 | 5.5s | into the next piece of YouTube, which is |
| 18:02 | 3.8s | now actually making the content. And the |
| 18:04 | 3.8s | most important piece about content is |
| 18:06 | 3.3s | actually what are your ideas? It's |
| 18:08 | 2.9s | funny, like when you think about making |
| 18:09 | 3.6s | YouTube videos, everyone thinks about |
| 18:11 | 3.0s | the editing. Everyone thinks about the |
| 18:13 | 1.4s | filming of the content. |
| 18:14 | 3.1s | >> Yeah. |
| 18:14 | 5.0s | >> But for YouTube specifically, the most |
| 18:17 | 4.1s | important part about making a video is |
| 18:19 | 5.1s | coming up with the idea for the video. |
| 18:21 | 5.9s | Because YouTube is more like Netflix. |
| 18:24 | 5.4s | It's more like Hollywood than it is like |
| 18:27 | 4.3s | social media because people have to see |
| 18:30 | 3.8s | your thumbnail, your title and |
| 18:31 | 4.1s | thumbnail, and click on it and decide to |
| 18:34 | 3.9s | watch that video. If they don't do that, |
| 18:35 | 3.0s | that one very important step, then it |
| 18:37 | 2.2s | doesn't really matter what you did |
| 18:38 | 2.3s | downstream from that. It doesn't matter |
| 18:40 | 2.2s | how great an edit is. It doesn't matter |
| 18:41 | 2.6s | how long it is. Doesn't matter if you |
| 18:42 | 3.0s | traveled to, I don't know, the Grand |
| 18:43 | 2.6s | Canyon and shot this vlog. If they don't |
| 18:45 | 1.6s | click on it, they're not going to see |
| 18:46 | 3.2s | anything. |
| 18:46 | 4.8s | >> Yeah. It's a click and commit platform. |
| 18:49 | 3.8s | >> Yeah. If if everyone's familiar with the |
| 18:51 | 3.7s | 8020 rule, which I think all of us |
| 18:53 | 4.8s | productivity nerds are, the 8020 rule |
| 18:55 | 5.4s | states that 20% of your efforts equal |
| 18:58 | 5.4s | 80% of your results, which means that |
| 19:00 | 4.6s | 80% of things that you could do don't |
| 19:03 | 3.4s | actually move the needle. And so the |
| 19:05 | 3.6s | things that you should focus on are |
| 19:06 | 3.4s | coming up with good ideas and then |
| 19:08 | 3.4s | titles and thumbnails. So let's talk |
| 19:10 | 3.3s | about like what makes really good ideas |
| 19:12 | 3.1s | for YouTube. So the first thing I would |
| 19:13 | 4.2s | say is like if you are a channel for |
| 19:15 | 4.0s | example, like ours was Koi, how do you |
| 19:17 | 3.4s | get better grades? Mhm. |
| 19:19 | 3.4s | >> We got together one day and we just |
| 19:21 | 3.0s | broke down what are all the different |
| 19:22 | 2.6s | study techniques, what are all the |
| 19:24 | 2.5s | learning principles, what are all the |
| 19:25 | 3.1s | productivity hacks that students would |
| 19:26 | 3.1s | need to get better grades and we just |
| 19:28 | 3.4s | mapped it out. We just drew everything. |
| 19:30 | 4.0s | It's like how to be more productive with |
| 19:32 | 3.8s | um with your calendar, how to time block |
| 19:34 | 3.0s | better, how to use active recall. |
| 19:35 | 2.7s | >> So the first thing I would say is yeah, |
| 19:37 | 3.1s | just map out all of the different topics |
| 19:38 | 2.9s | that you want to make content about. |
| 19:40 | 3.0s | That is the first step. Just see like |
| 19:41 | 4.3s | seeing okay, can you generate ideas on |
| 19:43 | 4.4s | your own for this topic or like for for |
| 19:45 | 4.7s | this space? Because if you can't come up |
| 19:47 | 4.5s | with ideas, um, then maybe you're in the |
| 19:50 | 2.7s | wrong niche. Maybe you have the wrong |
| 19:52 | 2.2s | transformation if you don't really know |
| 19:53 | 1.6s | what you can actually help people |
| 19:54 | 1.0s | achieve. |
| 19:54 | 2.1s | >> Mhm. |
| 19:55 | 3.0s | >> Now, the mistake that creators would |
| 19:56 | 3.3s | make now is just trying to make these |
| 19:58 | 4.2s | ideas as they are. Some of these video |
| 20:00 | 4.2s | ideas might be just super boring. Like, |
| 20:02 | 3.5s | nobody cares about it. The way I think |
| 20:04 | 4.6s | about this is that this is the medicine |
| 20:06 | 4.6s | that they need, but it tastes really |
| 20:09 | 3.3s | nasty, so they don't want to take it. |
| 20:10 | 3.8s | kind of like how like when my daughter |
| 20:12 | 4.4s | got sick, right? We had to give her like |
| 20:14 | 3.9s | some medicine, but it tastes really bad. |
| 20:16 | 4.0s | But when you mix it with something |
| 20:18 | 4.4s | tasty, like with some, you know, some |
| 20:20 | 3.8s | sweet drink or something or like putting |
| 20:22 | 3.4s | in her mashed potatoes or something, |
| 20:24 | 3.0s | >> then she'll be okay. Doesn't notice it |
| 20:26 | 3.2s | and she'll take it and then she'll get |
| 20:27 | 4.1s | the medicine. But that's how you want to |
| 20:29 | 3.9s | think about your audience as well is |
| 20:31 | 3.5s | that you want them to get this |
| 20:33 | 4.6s | knowledge. You want this knowledge to |
| 20:35 | 3.9s | change their life. They need it. But no |
| 20:37 | 3.2s | one's like waking up in the morning and |
| 20:39 | 6.4s | saying like, I want to learn how to use |
| 20:41 | 6.4s | flashcards. So, how do you package this |
| 20:45 | 3.3s | information into something that they |
| 20:47 | 3.9s | want to receive, they want to open, |
| 20:48 | 3.8s | they're excited to open this package and |
| 20:51 | 3.8s | get the knowledge. |
| 20:52 | 5.0s | >> That is the entire game of YouTube. |
| 20:55 | 5.0s | >> The good news is you don't have to guess |
| 20:57 | 4.9s | what a good idea is because there are |
| 21:00 | 4.5s | millions of creators on YouTube that |
| 21:02 | 5.6s | have already figured it Your job is to |
| 21:04 | 5.0s | find those videos, find that evidence. |
| 21:08 | 3.9s | These are videos that we call outlier |
| 21:09 | 3.9s | videos. An outlier video is basically a |
| 21:12 | 3.0s | video that performs better than the |
| 21:13 | 3.2s | average of that channel |
| 21:15 | 3.3s | >> because obviously not every single video |
| 21:16 | 2.0s | on a channel is going to hit. |
| 21:18 | 3.4s | >> Mhm. |
| 21:18 | 4.7s | >> But the ones that do, those ones worked |
| 21:21 | 4.8s | for a reason. So you want to analyze and |
| 21:23 | 5.4s | figure out why those videos worked and |
| 21:26 | 3.8s | kind of borrow ideas, imitate why it |
| 21:28 | 3.0s | worked for your own. I think a great |
| 21:30 | 3.4s | place to start is to go to all again go |
| 21:31 | 4.7s | to all your competitor channels go to |
| 21:33 | 4.4s | their video tab sort by most popular and |
| 21:36 | 3.4s | look at what are the videos that really |
| 21:38 | 3.7s | blew up their channel because odds are |
| 21:40 | 3.7s | like if they've gained you know any |
| 21:41 | 4.0s | traction there's usually just like one |
| 21:43 | 2.8s | or two videos that completely took off |
| 21:45 | 3.0s | for them |
| 21:46 | 4.0s | >> on our channel like for the longest time |
| 21:48 | 3.6s | it was this good notes versus notability |
| 21:50 | 3.0s | video like this video had like half a |
| 21:52 | 2.7s | million views and all the other ones |
| 21:53 | 2.9s | after that had like 30k views or |
| 21:55 | 2.9s | something like that there's always like |
| 21:56 | 2.6s | that one video that blows up and then |
| 21:57 | 3.0s | you get repeat ones and then you know |
| 21:59 | 3.0s | you can add to that bank of it. But most |
| 22:00 | 2.7s | channels that are growing, they'll have |
| 22:02 | 5.3s | just like this one breakout video, this |
| 22:03 | 6.3s | one outlier video. And so your job as a, |
| 22:07 | 4.2s | you know, creator now is to use YouTube |
| 22:09 | 3.8s | and have a different lens on like don't |
| 22:11 | 4.7s | just go to scroll mindlessly. Like study |
| 22:13 | 4.2s | the channels that are in your space. |
| 22:16 | 3.8s | Find out what they're doing well and |
| 22:17 | 4.1s | then try to give your take on what are |
| 22:20 | 3.0s | those popular ideas that they have |
| 22:22 | 2.2s | there. There's this format on YouTube |
| 22:23 | 3.8s | right now that's doing really well that |
| 22:24 | 5.0s | goes, "Give me 10 minutes or a certain |
| 22:26 | 4.8s | amount of minutes and I'll fix something |
| 22:29 | 4.3s | for you or I'll teach you how to be a |
| 22:31 | 4.7s | better learner. Can one of these topics |
| 22:33 | 4.2s | that you want to cover work with this |
| 22:36 | 2.9s | idea?" And that's a way that you can |
| 22:37 | 3.0s | just give it your twist. You don't |
| 22:39 | 2.9s | necessarily have to copy like the exact |
| 22:40 | 2.6s | ideas that they use in this video. |
| 22:42 | 2.6s | That's actually the whole point. You |
| 22:43 | 2.6s | don't want to copy like everything they |
| 22:44 | 2.6s | say in that video because then you're |
| 22:45 | 2.7s | just going to be a copycat. You just |
| 22:47 | 3.0s | want to borrow like what worked for |
| 22:48 | 2.4s | getting the click and then you give your |
| 22:50 | 2.8s | own take on it, |
| 22:51 | 4.4s | >> right? How are we just connecting the |
| 22:53 | 4.6s | right idea to the right psychology? |
| 22:55 | 6.2s | >> So, one thing that we love doing is we |
| 22:57 | 5.7s | use tools to help us rapidly identify |
| 23:01 | 3.5s | these outlier videos. |
| 23:03 | 5.5s | >> So, in your browser, you can download |
| 23:05 | 6.2s | extensions. Um, we use Vid IQ, we use |
| 23:08 | 4.2s | View Stats, and these are free, right? |
| 23:11 | 3.9s | You can just download them and it'll |
| 23:13 | 3.0s | show you an outlier score. |
| 23:15 | 3.9s | >> Mhm. |
| 23:16 | 5.2s | >> So, did the video do 10x better than the |
| 23:19 | 3.8s | average? Did it do a 100x better than |
| 23:21 | 4.0s | the average? Right? If you look hard |
| 23:23 | 2.6s | enough, you can find a 100x videos. |
| 23:25 | 2.5s | >> Yeah, |
| 23:25 | 4.5s | >> those are the videos to look at. What |
| 23:27 | 3.9s | about that video did so well? You want |
| 23:30 | 3.2s | to try to imitate that for your own |
| 23:31 | 3.5s | videos. If you try to like just steal |
| 23:33 | 4.0s | this complete package here, title, |
| 23:35 | 3.8s | thumbnail, and everything about it, your |
| 23:37 | 2.2s | video is going to get destroyed. |
| 23:38 | 2.3s | >> Mhm. |
| 23:39 | 5.4s | >> Why would someone click on your video |
| 23:41 | 5.4s | that has zero views, zero subscribers on |
| 23:44 | 3.2s | the channel versus a video that's got |
| 23:46 | 2.9s | like millions of views from a bigger |
| 23:48 | 3.1s | channel? which is why it's better to |
| 23:49 | 2.4s | just borrow ideas from it and then give |
| 23:51 | 2.3s | it your take. |
| 23:51 | 3.8s | >> And this very thing happened to us |
| 23:53 | 5.1s | actually. So there was a video we had, |
| 23:55 | 5.4s | it was the 2inut video. That video, |
| 23:58 | 4.9s | people actually stole that video and |
| 24:01 | 3.7s | re-uploaded on their channel. And when I |
| 24:03 | 4.0s | went through like the copyright section |
| 24:04 | 5.7s | in our YouTube analytics, there were |
| 24:07 | 4.7s | dozens of channels that literally copied |
| 24:10 | 4.2s | the exact packaging, exact thing. Some |
| 24:12 | 4.7s | of them even had the exact video just |
| 24:14 | 5.1s | changed to a different language |
| 24:16 | 5.6s | >> re-uploaded on their channel. And I will |
| 24:19 | 3.7s | say that none of them broke like a,000 |
| 24:22 | 3.2s | views. |
| 24:23 | 4.2s | >> It just doesn't work. Like if you copy |
| 24:25 | 5.4s | another video, the algorithm is going to |
| 24:27 | 5.0s | show you this 100x versus zero and |
| 24:31 | 3.5s | people are going to go with the 100x |
| 24:32 | 4.0s | every single time. Like there's no way |
| 24:34 | 3.8s | to win when you just completely copy, |
| 24:36 | 3.4s | >> right? This is like the way that we've |
| 24:38 | 2.8s | seen so many of our clients and so many |
| 24:39 | 4.6s | other channels really taking off right |
| 24:41 | 5.0s | now. So, like we said, this is the 20% |
| 24:44 | 3.4s | of the work that's going to get you 80% |
| 24:46 | 3.6s | of the results right here. Kind of |
| 24:47 | 4.2s | paradoxical, kind of backwards to what |
| 24:49 | 4.4s | you might think, but most of your |
| 24:52 | 3.8s | efforts should live here. Coming up with |
| 24:54 | 2.8s | really good ideas and packaging them. |
| 24:55 | 2.4s | So, let's quickly talk about, you know, |
| 24:57 | 2.8s | how do you actually make your videos? |
| 24:58 | 3.1s | The good news now is that, you know, in |
| 24:59 | 3.0s | 2026, |
| 25:01 | 3.0s | all of our devices are just getting |
| 25:02 | 2.8s | better and better. Technology is just |
| 25:04 | 3.7s | getting way better. Like, we just |
| 25:05 | 4.8s | upgraded our phones from to the new |
| 25:08 | 5.0s | iPhone 17 Pros. I might not even need a |
| 25:10 | 5.3s | camera anymore. Like the 4K in this |
| 25:13 | 4.1s | camera, this this phone is so good. Like |
| 25:15 | 2.7s | we could be filming this right now with |
| 25:17 | 4.2s | a camera if we wanted to. I would say |
| 25:18 | 4.4s | for making videos, the two things that |
| 25:21 | 3.4s | you if you want to invest in anything to |
| 25:22 | 3.9s | make high quality videos, number one is |
| 25:24 | 3.7s | a microphone and two is a light. A |
| 25:26 | 1.9s | bigger light with a with a soft box. |
| 25:28 | 1.8s | >> Yeah. |
| 25:28 | 3.0s | >> So a softbox is basically just this |
| 25:30 | 3.4s | cover that goes over the light that |
| 25:31 | 3.6s | diffuses the light so it's not so harsh. |
| 25:33 | 2.5s | It makes these like soft shadows on your |
| 25:35 | 2.4s | face and it just looks very |
| 25:36 | 3.1s | professional. So, in terms of gear, |
| 25:37 | 3.0s | that's all you really need to make good |
| 25:39 | 3.3s | videos. So, now let's move on to |
| 25:40 | 4.2s | actually making your YouTube videos. |
| 25:42 | 3.5s | Now, again, we're like speaking more |
| 25:44 | 3.1s | specifically for like educational |
| 25:46 | 3.4s | content, which usually means you're |
| 25:48 | 3.0s | going to be teaching or helping people |
| 25:49 | 3.0s | solve some kind of problem. And usually, |
| 25:51 | 3.4s | you're going to be talking, |
| 25:52 | 3.5s | >> right? It's either yourself on camera or |
| 25:54 | 2.6s | it's a voiceover or something like that. |
| 25:56 | 3.0s | But, whatever you're going to do, |
| 25:57 | 3.4s | there's going to be some kind of outline |
| 25:59 | 3.4s | or script that you need. We usually |
| 26:00 | 3.4s | outline the videos first just to get the |
| 26:02 | 2.9s | structural ideas out. you know, like |
| 26:03 | 2.6s | maybe like what kind of framework, what |
| 26:05 | 2.6s | are the points that we want to cover, |
| 26:06 | 2.9s | how do they work together, how do they |
| 26:07 | 3.0s | fit together, and then once we have a |
| 26:09 | 3.0s | good outline, then we'll script out a |
| 26:10 | 3.3s | few parts. I don't think you have to |
| 26:12 | 3.1s | script out your whole videos word for |
| 26:14 | 3.4s | word. I know some creators like to do |
| 26:15 | 4.6s | that, but we've been moving more towards |
| 26:17 | 4.6s | this like extemporaneous off-the cuff |
| 26:20 | 4.3s | teaching style because it just feels |
| 26:22 | 4.8s | more natural. One, it makes you come off |
| 26:24 | 4.6s | less robotic, but also scripting word |
| 26:26 | 3.8s | for word takes a long time, especially |
| 26:29 | 4.5s | if you're not a writer. Like we have |
| 26:30 | 4.0s | some clients who spend 5 to 10 hours |
| 26:33 | 3.1s | writing a script |
| 26:34 | 3.2s | >> for like I don't know an 8minute video |
| 26:36 | 1.7s | or something like that. That's a lot of |
| 26:38 | 1.5s | time. |
| 26:38 | 2.4s | >> Yeah, that's too much. That's |
| 26:39 | 2.5s | overthinking even. |
| 26:40 | 2.6s | >> Yeah, that's like way too much time like |
| 26:42 | 2.7s | tweaking some grammar and stuff like |
| 26:43 | 3.3s | that. And so I think you're much better |
| 26:44 | 3.4s | off like getting your ideas out there |
| 26:46 | 2.6s | like outlining the video in terms of |
| 26:48 | 2.3s | like these are the stories that I might |
| 26:49 | 3.1s | want to tell. These are some of the |
| 26:50 | 3.7s | things I want to site. Um and then just |
| 26:52 | 3.3s | letting yourself naturally be on camera |
| 26:54 | 3.4s | because in 2026 right now like with the |
| 26:55 | 5.2s | surge of AI, authenticity is the |
| 26:57 | 5.0s | advantage. If you go to a channel and |
| 27:00 | 3.6s | someone is reading an AI script, like |
| 27:02 | 4.5s | it's pretty obvious. Like I use chatp |
| 27:04 | 4.6s | every single day and I can recognize if |
| 27:07 | 4.3s | someone is reading a chat script. |
| 27:09 | 4.2s | >> The notorious line is I will give you |
| 27:11 | 5.4s | this. No fluff, |
| 27:13 | 4.6s | >> no BS, just plain whatever. Like that is |
| 27:16 | 2.4s | so AI to me. |
| 27:17 | 1.9s | >> Yeah, that one. Or like here's the |
| 27:19 | 1.6s | kicker. |
| 27:19 | 2.6s | >> Yeah, here's the kicker. |
| 27:20 | 3.6s | >> Yeah. Yeah. I think AI is a great |
| 27:22 | 3.4s | outliner. Um, you should use it to |
| 27:24 | 3.3s | outline and you can use it to like |
| 27:25 | 3.4s | revise your writing and stuff, but |
| 27:27 | 3.3s | always try to speak from the heart. I |
| 27:29 | 2.7s | think that's what builds trust more with |
| 27:30 | 2.2s | your audience than anything else. |
| 27:32 | 2.6s | Especially if you're making educational |
| 27:33 | 3.2s | content. I mean, sometimes if you make |
| 27:34 | 3.7s | mistakes, you could also leave it in |
| 27:36 | 4.3s | there if you want to cuz you're just |
| 27:38 | 4.8s | human. It does make everything easier if |
| 27:40 | 4.3s | you plan. Like right now, it feels like |
| 27:43 | 3.8s | we're just kind of talking off the cuff, |
| 27:45 | 3.1s | but we do have an outline right here. |
| 27:46 | 3.3s | like we know the points that we want to |
| 27:48 | 3.5s | hit, but have an outline so that you |
| 27:50 | 2.8s | know the points you want to hit and the |
| 27:51 | 2.6s | points that you don't want to miss. |
| 27:53 | 3.8s | Right? At the end of the day, you're |
| 27:54 | 4.7s | teaching people how to do something for |
| 27:56 | 5.1s | actually editing the videos. That would |
| 27:58 | 4.3s | be a I don't know, a 10-hour video that |
| 28:01 | 3.4s | we'd have to make about how to edit |
| 28:03 | 3.4s | really high quality videos. |
| 28:05 | 2.8s | >> It's so variable, though. Like, you |
| 28:06 | 3.4s | know, every creator on the platform has |
| 28:08 | 3.9s | a different style. Um, a lot of creators |
| 28:10 | 3.7s | even work with outside editors, and I |
| 28:12 | 3.7s | actually highly encourage that you work |
| 28:13 | 4.6s | with editors who know what they're |
| 28:15 | 4.2s | doing, and some editors can do a much |
| 28:18 | 3.4s | better job than you. It's probably a |
| 28:19 | 3.3s | better use of your time to focus here on |
| 28:21 | 2.8s | the uh on the ideas and the and the |
| 28:23 | 4.5s | packaging anyways. But what you |
| 28:24 | 4.7s | absolutely want to do is to create |
| 28:27 | 3.2s | templates every single time you're |
| 28:29 | 3.8s | making a new video. You're not starting |
| 28:30 | 3.9s | from scratch. You're not reinventing the |
| 28:33 | 4.0s | wheel every time. So, for example, there |
| 28:34 | 4.8s | are templates where you can just |
| 28:37 | 4.7s | one-click drag and drop an entire like |
| 28:39 | 4.8s | color grading onto your videos. There's |
| 28:41 | 4.4s | templates for scripting as well. Like, |
| 28:44 | 2.9s | if you have a certain structure to your |
| 28:46 | 3.0s | videos, |
| 28:47 | 5.0s | >> um, we've actually designed like there's |
| 28:49 | 4.5s | hook frameworks and storytelling |
| 28:52 | 3.2s | frameworks. You can figure out |
| 28:53 | 4.1s | everything and kind of lay it out. It |
| 28:55 | 4.7s | makes planning so much easier and it |
| 28:57 | 3.4s | makes the whole process efficient. I |
| 29:00 | 3.9s | mean, that's not something you need to |
| 29:01 | 7.1s | have done by your first video. |
| 29:04 | 4.1s | trying to get all of those |
| 29:09 | 5.4s | like volume so |
| 29:12 | 3.8s | >> that we did this at least for our |
| 29:14 | 4.2s | channel every video that we made we |
| 29:16 | 3.7s | would just make one new template |
| 29:18 | 2.8s | >> you know it's like okay this video the |
| 29:20 | 3.0s | template that I made was this color |
| 29:21 | 3.5s | grading template so the next video I |
| 29:23 | 3.7s | already have that done now let's work on |
| 29:25 | 3.9s | like this animation template where the |
| 29:27 | 3.2s | text pops in now I have two templates |
| 29:28 | 2.3s | you know then the next video you add |
| 29:30 | 2.6s | another one on you know and just keep |
| 29:31 | 3.1s | adding on until you have You don't need |
| 29:32 | 3.3s | a million templates, too, by the way. |
| 29:34 | 3.5s | You just need like, I don't know, just |
| 29:36 | 3.8s | enough to to create this vibe and this |
| 29:37 | 3.7s | style for your content. We've built so |
| 29:39 | 3.0s | many templates over the years. We've |
| 29:41 | 2.5s | built templates for clients. We've built |
| 29:42 | 2.9s | templates for our own channels and |
| 29:44 | 2.7s | stuff. And so, if you're interested in |
| 29:45 | 2.6s | grabbing some of the templates that |
| 29:46 | 3.3s | we've made, these are available to all |
| 29:48 | 3.0s | of the people we work with. Um, links in |
| 29:50 | 2.8s | the description below. Check it out. But |
| 29:51 | 3.2s | now, let's move on to everyone's |
| 29:52 | 2.2s | favorite part about YouTube, how you |
| 29:54 | 3.2s | make money. |
| 29:55 | 4.7s | >> So, to think about this very simply, |
| 29:57 | 4.2s | there are only really two ways that you |
| 29:59 | 4.8s | can make money with YouTube. You can |
| 30:01 | 4.9s | sell your own thing or you can sell |
| 30:04 | 4.3s | someone else's thing. So when it comes |
| 30:06 | 5.6s | to selling your own thing, there are |
| 30:08 | 6.9s | basically three things. You can sell |
| 30:12 | 7.4s | your own products, you can sell your own |
| 30:15 | 5.9s | services, and you can sell experiences. |
| 30:19 | 4.2s | Not to make it more confusing, but each |
| 30:21 | 3.9s | of these three can also be split up into |
| 30:24 | 3.4s | like subcategories. |
| 30:25 | 3.5s | >> For example, for products, you can sell |
| 30:27 | 4.0s | digital products. So, these are like |
| 30:29 | 3.6s | downloadables, templates, |
| 30:31 | 2.6s | um I don't know, any of those like |
| 30:32 | 2.7s | templates we just talked about for video |
| 30:34 | 4.6s | editing and stuff like that. Uh |
| 30:35 | 5.0s | workbooks, ebooks. I think there's a big |
| 30:38 | 3.7s | advantage for educational channels or |
| 30:40 | 3.0s | educational creators to make digital |
| 30:42 | 3.3s | products because the margins are really |
| 30:43 | 4.3s | favorable for you. Or you can sell |
| 30:45 | 3.8s | physical products, things like t-shirts, |
| 30:47 | 4.0s | I don't know, things like uh water |
| 30:49 | 4.8s | bottles, uh notebooks. I've seen some |
| 30:51 | 5.2s | creators selling notebooks, uh matcha. |
| 30:54 | 6.2s | So, for services, there are also two |
| 30:57 | 5.6s | categories. You either can do something |
| 31:00 | 4.6s | for somebody like if someone pays me |
| 31:02 | 5.0s | like hey I want you to |
| 31:04 | 4.5s | >> create a poster for me then you will go |
| 31:07 | 5.0s | and make the poster for them |
| 31:09 | 5.2s | >> or you can do it with them. So hey I |
| 31:12 | 3.4s | want to make a poster I need your help |
| 31:14 | 3.5s | making this poster. So you can guide |
| 31:16 | 4.2s | them you can consult with them. You can |
| 31:18 | 4.6s | coach them you can give them resources |
| 31:20 | 4.2s | to make the poster easier but in general |
| 31:22 | 3.7s | it's done with you or done for you. |
| 31:24 | 3.1s | Yeah. And finally for experiences, I |
| 31:26 | 2.6s | guess there are again two different |
| 31:27 | 3.0s | types of experiences. You can have |
| 31:29 | 2.9s | virtual experiences or you can have |
| 31:30 | 3.4s | inerson experiences. |
| 31:31 | 5.0s | >> So if you look at every single one of |
| 31:34 | 5.0s | these categories, there are millionaires |
| 31:36 | 3.9s | if not billionaires in every single one. |
| 31:39 | 2.6s | So what I'm saying is like they will all |
| 31:40 | 2.6s | work. |
| 31:41 | 4.4s | >> It's just a matter of what do you want |
| 31:43 | 4.7s | to do? What what best fits you? Do you |
| 31:46 | 4.0s | like to say coach people and help them |
| 31:48 | 3.6s | do things or do you want to just build a |
| 31:50 | 3.4s | product and have it done for them and |
| 31:51 | 3.3s | ship it to them? Right? So it it really |
| 31:53 | 3.0s | depends on who you are and what you want |
| 31:55 | 2.0s | to do, what your business is trying to |
| 31:56 | 2.2s | do. |
| 31:57 | 4.2s | >> But at the end of the day, every single |
| 31:58 | 4.1s | one of these things, they help people go |
| 32:01 | 3.9s | through a transformation. So for |
| 32:02 | 4.2s | example, for our channel, the |
| 32:05 | 2.6s | transformation is getting better grades. |
| 32:06 | 2.2s | >> Mhm. |
| 32:07 | 4.2s | >> We have actually tried every single one |
| 32:09 | 5.1s | of these to some extent, right? So we |
| 32:11 | 4.0s | have digital products in terms of |
| 32:14 | 3.7s | templates, courses. |
| 32:15 | 6.4s | >> Mhm. We have physical products in terms |
| 32:18 | 5.0s | of like books or I guess we had some |
| 32:22 | 2.1s | merch. |
| 32:23 | 4.2s | >> Yeah, we stopped doing the merch. |
| 32:24 | 3.8s | >> Yeah, we had like a cozy study hoodie or |
| 32:27 | 3.4s | something. |
| 32:28 | 4.0s | >> So, for services, right, we are in the |
| 32:30 | 3.4s | YouTube education space. |
| 32:32 | 4.1s | >> So, we do have programs where we will |
| 32:34 | 4.0s | coach you and help you grow your YouTube |
| 32:36 | 4.3s | channel and make money from YouTube. But |
| 32:38 | 4.6s | we also have uh an agency side where we |
| 32:40 | 3.8s | just do everything for you. We come up |
| 32:42 | 3.7s | with the ideas, we make the videos, we |
| 32:44 | 3.6s | edit the videos, and we upload it for |
| 32:46 | 3.3s | you. And for experiences, I will say |
| 32:48 | 4.2s | that live events is something that we're |
| 32:49 | 5.2s | shooting for. But we've had plenty of uh |
| 32:52 | 5.6s | online virtual experiences. We've had |
| 32:54 | 5.6s | like uh communities, memberships, we've |
| 32:57 | 4.2s | had, you know, webinars. These are just |
| 33:00 | 3.7s | ways for our community to come together |
| 33:02 | 4.2s | and all learn together and all support |
| 33:04 | 4.2s | each other. of the three over here. I |
| 33:06 | 4.4s | think if you are an educationbased |
| 33:08 | 5.0s | company, there's a really strong |
| 33:10 | 4.3s | argument for starting off in the |
| 33:13 | 4.0s | services category. Specifically for |
| 33:14 | 3.8s | that, I mean like one-on-one something. |
| 33:17 | 3.4s | >> Either that's one-on-one coaching, |
| 33:18 | 3.4s | one-on-one consulting, one-on-one like |
| 33:20 | 3.0s | we'll do the thing for you or do with |
| 33:22 | 3.9s | you. But like you need to get that |
| 33:23 | 5.0s | really intimate hightouch feedback from |
| 33:26 | 4.5s | somebody. Like it's so much faster to |
| 33:28 | 3.9s | help someone by holding their hand and |
| 33:30 | 3.0s | working with them closely than it is to |
| 33:32 | 2.6s | just give them a course and be like, |
| 33:33 | 3.1s | "Hey, have at it." Like figure out on |
| 33:35 | 2.7s | your own. You'll be able to grow your |
| 33:36 | 1.8s | business a lot faster if you start with |
| 33:38 | 2.2s | services. |
| 33:38 | 4.6s | >> Yeah. Cuz at the end of the day, it all |
| 33:40 | 4.3s | comes to getting the people the result, |
| 33:43 | 3.7s | >> getting people the transformation that |
| 33:44 | 4.3s | they want. Like so for us, we did have |
| 33:46 | 4.2s | products where it would teach people how |
| 33:48 | 3.1s | to get better grades. We would put it on |
| 33:50 | 3.5s | the store |
| 33:51 | 4.9s | >> and then people would buy it and they a |
| 33:54 | 4.4s | lot of them would not get better grades, |
| 33:56 | 5.2s | right? None of them would not get the |
| 33:58 | 5.5s | results because it's really up to them |
| 34:02 | 3.7s | to actually take action on what they |
| 34:04 | 2.6s | bought. Like you said, like not only is |
| 34:05 | 2.7s | it going to make your products better |
| 34:06 | 2.7s | and your experiences better, but it's |
| 34:08 | 2.4s | going to make your content better. |
| 34:09 | 2.1s | >> Oh, absolutely. Right? That that's |
| 34:10 | 2.7s | actually probably one of the biggest |
| 34:11 | 3.6s | reasons why services is so good because |
| 34:13 | 5.4s | you learn about what are the problems |
| 34:15 | 5.4s | that my customer actually has. And if |
| 34:18 | 3.9s | you make content about that thing later |
| 34:20 | 3.4s | on and answer the exact questions and |
| 34:22 | 2.8s | pain points they have, you're going to |
| 34:24 | 2.8s | attract so many more people into your |
| 34:25 | 3.1s | business because they're like, "Oh, the |
| 34:26 | 3.7s | content is speaking to the exact |
| 34:28 | 3.1s | problems that I have." All those topics |
| 34:30 | 2.3s | we talked about earlier, like you're not |
| 34:31 | 3.0s | guessing about what those are anymore. |
| 34:32 | 3.3s | Like you know from working with people |
| 34:34 | 2.7s | like what they actually have problems |
| 34:36 | 4.1s | with. And last thing I'll say about |
| 34:37 | 5.5s | pitching services, for services, you can |
| 34:40 | 4.6s | generally charge higher prices than for |
| 34:43 | 3.3s | products and you're investing your time |
| 34:44 | 3.0s | and you're being present with them |
| 34:46 | 3.1s | there. And people will pay a lot more |
| 34:47 | 3.0s | for services. I'm talking about like, |
| 34:49 | 4.1s | you know, in the thousands of dollars |
| 34:50 | 4.0s | for services versus products which can |
| 34:53 | 3.6s | range, you know, from, you know, |
| 34:54 | 3.4s | something like a $5 digital product up |
| 34:57 | 2.7s | to, you know, I think some courses can |
| 34:58 | 3.3s | run to like $1,000 or something like |
| 34:59 | 4.9s | that. But usually those thousand dollar |
| 35:01 | 4.7s | courses have inside of them like other |
| 35:04 | 3.2s | experiences or other like perks and |
| 35:06 | 3.1s | benefits to them, right? Usually it's |
| 35:07 | 3.1s | not just a course anymore. All right, so |
| 35:09 | 2.6s | what about this side? Yeah, let's go to |
| 35:11 | 3.1s | the other side. This one's a little bit |
| 35:12 | 4.6s | simpler. So this was selling your own |
| 35:14 | 4.5s | stuff. On this side, we have selling |
| 35:16 | 4.2s | other people's stuff. And to make this |
| 35:18 | 7.5s | simple as well, there are three |
| 35:20 | 8.7s | categories. First one is AdSense. |
| 35:26 | 5.4s | Next is brand deals, also commonly |
| 35:29 | 4.1s | called sponsorships. And third would be |
| 35:31 | 5.8s | affiliate income. Basically, all three |
| 35:33 | 6.2s | of these are you partnering with some |
| 35:37 | 4.2s | other brand or some other company. |
| 35:40 | 3.2s | >> The first one is easy to understand. |
| 35:41 | 3.5s | This is you partnering with YouTube, |
| 35:43 | 6.1s | right? This is YouTube's partner |
| 35:44 | 7.2s | program. It pays you in AdSense revenue. |
| 35:49 | 5.1s | >> And depending on the niche, your AdSense |
| 35:52 | 4.2s | revenue can be really, really high or |
| 35:54 | 3.6s | really, really low. for example, like |
| 35:56 | 4.0s | yeah, I know the creators in like the |
| 35:58 | 4.2s | finance or the real estate niche, like |
| 36:00 | 4.4s | Graham Stefen, for example, is a big |
| 36:02 | 4.6s | one. They can make so much money from ad |
| 36:04 | 3.8s | revenue because the brands that partner |
| 36:06 | 4.0s | with YouTube that put their ads in your |
| 36:08 | 4.5s | videos are willing to pay you a lot more |
| 36:10 | 4.1s | money. Those are called RPMs, right? How |
| 36:13 | 2.9s | much a brand is willing to pay for that |
| 36:14 | 2.0s | ad spot. |
| 36:15 | 2.0s | >> The [clears throat] finance space and |
| 36:16 | 3.1s | the real estate space, for example, will |
| 36:17 | 3.5s | pay a lot more than for example the |
| 36:20 | 3.7s | study space |
| 36:21 | 3.7s | >> or the productivity or the comedy space. |
| 36:23 | 2.4s | So that's why it's really important to |
| 36:25 | 2.5s | figure out your niche. |
| 36:26 | 4.0s | >> It's also important to note that you |
| 36:27 | 4.6s | won't just start making AdSense revenue |
| 36:30 | 3.6s | from YouTube immediately. There are some |
| 36:32 | 3.3s | requirements to enter the partner |
| 36:33 | 4.3s | program. You need at least I think it's |
| 36:35 | 4.3s | 1,000 subscribers and 4,000 hours of |
| 36:38 | 3.8s | watch time within the past year. So once |
| 36:39 | 3.1s | you hit those numbers, um you can start |
| 36:41 | 3.5s | making AdSense revenue. |
| 36:42 | 6.2s | >> 4,000. It does sound like a lot, |
| 36:45 | 5.7s | >> but some people can get monetized and |
| 36:49 | 3.7s | get the partner program in like a single |
| 36:50 | 3.3s | video if the video gets 4,000 watch |
| 36:52 | 2.7s | hours. Mhm. Yeah. I mean, you can get |
| 36:54 | 2.7s | one video that blows up and then that |
| 36:55 | 3.0s | monetizes your channel. We've had many |
| 36:56 | 2.5s | clients who've just like gotten one |
| 36:58 | 2.5s | video and then suddenly they're |
| 36:59 | 3.7s | monetized and making like 500 bucks. |
| 37:00 | 5.4s | >> So, for these other two ways, this is |
| 37:03 | 4.7s | you partnering with any other brand or |
| 37:06 | 3.4s | company. It doesn't necessarily have to |
| 37:07 | 5.6s | be YouTube. We have partnered with |
| 37:09 | 7.5s | companies like Notion, uh like Amazon, |
| 37:13 | 7.2s | like uh ConvertKit, like Dcript. Um, so |
| 37:17 | 4.6s | whatever companies that match the |
| 37:20 | 2.7s | transformation that you're helping |
| 37:21 | 3.3s | people achieve, you want to think about |
| 37:23 | 3.7s | that ahead of time so that you can build |
| 37:25 | 3.0s | an audience that other companies would |
| 37:27 | 1.6s | want to pay for. |
| 37:28 | 2.2s | >> Mhm. |
| 37:28 | 5.2s | >> So the difference between these two is |
| 37:30 | 5.4s | that for brand deals, a company is |
| 37:33 | 4.6s | sponsoring one of your videos. They will |
| 37:35 | 4.7s | give you money for you to talk about |
| 37:38 | 4.6s | their products in your video. For |
| 37:40 | 4.6s | affiliates, you're basically making a |
| 37:43 | 3.6s | commission every time someone buys |
| 37:45 | 3.0s | something from that company. So, we've |
| 37:46 | 5.4s | had videos where we talk about things |
| 37:48 | 6.2s | like supplements or medical devices, and |
| 37:52 | 4.1s | we kind of compare like which one we |
| 37:54 | 4.6s | think is better. When people buy one of |
| 37:56 | 4.7s | those, then we get a small percentage of |
| 37:59 | 4.4s | that purchase. And again, just like this |
| 38:00 | 4.6s | side, if you look at every single one of |
| 38:03 | 4.5s | these methods, you will find |
| 38:05 | 4.8s | millionaires and potentially |
| 38:07 | 4.4s | billionaires in all of these. So, yes, |
| 38:10 | 4.5s | they all work. But I would say for brand |
| 38:12 | 5.3s | deals, on average, you can earn a lot |
| 38:14 | 4.5s | more compared to AdSense and affiliate. |
| 38:17 | 3.5s | Even in the education space right now, I |
| 38:19 | 3.7s | used to think that like selling your own |
| 38:21 | 3.8s | thing, you can make a lot more money, |
| 38:22 | 4.6s | but there are many educational creators |
| 38:24 | 3.7s | who make a ridiculous amount of money |
| 38:27 | 3.1s | from brand deals. |
| 38:28 | 3.8s | >> Mhm. um because they were able to |
| 38:30 | 3.7s | negotiate brand deals that extend for |
| 38:32 | 3.4s | more than just one video. Some of them |
| 38:34 | 2.6s | even sign like a whole yearly contract |
| 38:35 | 2.8s | with a company. |
| 38:36 | 3.4s | >> It's like every like once a month I'll |
| 38:38 | 4.0s | post a video and they'll give you like a |
| 38:40 | 3.5s | big lumpsum salary almost like you can |
| 38:42 | 3.0s | cover your whole expenses for your whole |
| 38:43 | 2.6s | company year um if you get the right |
| 38:45 | 2.7s | brand deal. |
| 38:46 | 3.8s | >> And so don't sleep on brand deals. Um |
| 38:48 | 4.1s | but again like we said like there's no |
| 38:50 | 3.9s | right or wrong way to make money and you |
| 38:52 | 4.2s | should definitely explore |
| 38:54 | 3.8s | >> multiple of these um to see what works |
| 38:56 | 3.2s | best for your brand and your company. |
| 38:58 | 4.4s | But once you find one that's working, I |
| 38:59 | 5.4s | would definitely like tap into it more. |
| 39:02 | 4.8s | For example, our business, most of our |
| 39:05 | 3.1s | money was made through products and |
| 39:07 | 2.6s | services, right? Like that's where we |
| 39:08 | 2.8s | make the bulk of our money. We have made |
| 39:09 | 2.8s | a lot of brand deal money too, but like |
| 39:11 | 3.2s | we noticed that these levers were |
| 39:12 | 4.0s | working really well and so we invested |
| 39:14 | 3.5s | more effort and energy into making those |
| 39:16 | 3.3s | work better and better. I think there is |
| 39:18 | 3.6s | a mistake of trying to diversify into |
| 39:19 | 4.2s | all of these too quickly |
| 39:21 | 4.7s | >> at the risk, right? It's like if you try |
| 39:24 | 3.7s | to do three things at once, you're not |
| 39:26 | 2.4s | going to do as well as doing one thing |
| 39:27 | 3.4s | really, really well. |
| 39:28 | 6.2s | >> And the reason is because each one of |
| 39:31 | 5.6s | these, they have a different system. If |
| 39:34 | 4.5s | you want to get brand deals all the |
| 39:36 | 4.6s | time, you need to be out there talking |
| 39:39 | 4.0s | to brands, getting in front of them, |
| 39:41 | 3.7s | negotiating with brands, |
| 39:43 | 4.0s | >> building relationships with them, and |
| 39:45 | 4.2s | that is a whole process, right? That |
| 39:47 | 4.0s | takes a lot of time. But on the other |
| 39:49 | 4.5s | hand, if you want to do something like, |
| 39:51 | 4.2s | you know, services, then you need to be |
| 39:53 | 4.0s | out there pitching your idea to |
| 39:55 | 4.6s | customers, getting on sales calls, |
| 39:57 | 3.8s | potentially um evaluating your customers |
| 40:00 | 3.8s | to make sure that they're actually a |
| 40:01 | 4.7s | good fit for your your services, and |
| 40:04 | 3.8s | then actually delivering the services. |
| 40:06 | 2.6s | That also takes a lot of time. I |
| 40:07 | 3.2s | probably just named like three different |
| 40:08 | 4.4s | systems in there or subsystems, |
| 40:10 | 4.4s | >> but as you can see, like these two |
| 40:13 | 3.5s | systems are very different. Mhm. |
| 40:15 | 3.5s | >> And so if you're trying to do all these |
| 40:16 | 4.2s | at the same time and diversify at the |
| 40:18 | 4.5s | same time in the very beginning, we see |
| 40:20 | 5.6s | a lot of creators that fail, they try to |
| 40:23 | 5.8s | diversify too fast at once, they have |
| 40:26 | 4.2s | half built systems and their entire |
| 40:29 | 2.2s | company just falls apart. |
| 40:30 | 3.3s | >> Mhm. |
| 40:31 | 4.0s | >> Now, the one thing that connects all of |
| 40:34 | 2.4s | these together, that sits right in the |
| 40:35 | 2.2s | middle here, and it connects to |
| 40:36 | 3.5s | everything that we talked about in this |
| 40:37 | 4.4s | video, is none of this can work unless |
| 40:39 | 3.7s | you have really good content. |
| 40:41 | 3.4s | >> Right? Content sits at the middle of all |
| 40:43 | 3.0s | of monetization here because if you |
| 40:45 | 2.9s | don't have content, you don't have |
| 40:46 | 3.5s | attention on your channel. You don't |
| 40:48 | 3.2s | have eyeballs that you can monetize, |
| 40:50 | 3.0s | right? No one's going to come buy your |
| 40:51 | 2.9s | products and services. No one's going to |
| 40:53 | 2.3s | give you AdSense money. No brand's going |
| 40:54 | 3.4s | to want to work with you if you don't |
| 40:55 | 4.5s | have good content. And so content |
| 40:57 | 4.6s | unlocks all of this stuff. So again, |
| 40:59 | 4.2s | focus on making this really strong. And |
| 41:02 | 4.0s | then you can also build these things on |
| 41:04 | 3.1s | the back end or use these things if you |
| 41:06 | 2.5s | already have them. Like if you're an |
| 41:07 | 3.9s | established business and you don't have |
| 41:08 | 4.4s | content, then make sure you use that to |
| 41:11 | 3.8s | make good content. Everything also |
| 41:13 | 3.9s | always comes back to the content. |
| 41:14 | 4.2s | >> So if you are struggling with creating |
| 41:17 | 4.8s | content, if you don't have a system or a |
| 41:19 | 5.7s | process to create consistent highquality |
| 41:21 | 5.0s | content, then that's exactly what we |
| 41:24 | 5.6s | specialize in. If you're very serious |
| 41:26 | 6.2s | about approaching YouTube like a proper |
| 41:30 | 4.1s | business, we can help you build out your |
| 41:32 | 4.9s | products, build out your revenue |
| 41:34 | 5.3s | streams, build out an entire system that |
| 41:37 | 3.8s | will make you in and potentially give |
| 41:39 | 3.4s | you more options in life. Maybe you'll |
| 41:41 | 3.5s | find like us that you really really |
| 41:43 | 3.3s | enjoyed the process of making videos. I |
| 41:45 | 3.9s | don't see myself stopping doing this |
| 41:46 | 5.0s | anytime soon. And so I think YouTube as |
| 41:49 | 3.9s | a like career path now, it's something |
| 41:51 | 3.4s | that never existed before. like I |
| 41:53 | 3.4s | actually get to do things that I enjoy |
| 41:54 | 3.6s | every single day and actually make |
| 41:56 | 3.8s | income like a full-time income from it. |
| 41:58 | 3.0s | And so the opportunity has never been |
| 42:00 | 2.6s | better. Like I said, the window is |
| 42:01 | 3.3s | closing. I know we covered everything |
| 42:02 | 3.7s | really, really fast in this video, but |
| 42:04 | 5.3s | if you want like a full deep dive, like |
| 42:06 | 5.2s | a threehour masterass video into our |
| 42:10 | 3.5s | entire YouTube system, then definitely |
| 42:11 | 5.1s | check out this video right here. It's |
| 42:13 | 3.4s | going to be everything you wanted and |
